#define _CFFI_

/* We try to define Py_LIMITED_API before including Python.h.

   Mess: we can only define it if Py_DEBUG, Py_TRACE_REFS and
   Py_REF_DEBUG are not defined.  This is a best-effort approximation:
   we can learn about Py_DEBUG from pyconfig.h, but it is unclear if
   the same works for the other two macros.  Py_DEBUG implies them,
   but not the other way around.

   The implementation is messy (issue #350): on Windows, with _MSC_VER,
   we have to define Py_LIMITED_API even before including pyconfig.h.
   In that case, we guess what pyconfig.h will do to the macros above,
   and check our guess after the #include.

   Note that on Windows, with CPython 3.x, you need >= 3.5 and virtualenv
   version >= 16.0.0.  With older versions of either, you don't get a
   copy of PYTHON3.DLL in the virtualenv.  We can't check the version of
   CPython *before* we even include pyconfig.h.  ffi.set_source() puts
   a ``#define _CFFI_NO_LIMITED_API'' at the start of this file if it is
   running on Windows < 3.5, as an attempt at fixing it, but that's
   arguably wrong because it may not be the target version of Python.
   Still better than nothing I guess.  As another workaround, you can
   remove the definition of Py_LIMITED_API here.

   See also 'py_limited_api' in cffi/setuptools_ext.py.
*/
#if !defined(_CFFI_USE_EMBEDDING) && !defined(Py_LIMITED_API)
#  ifdef _MSC_VER
#    if !defined(_DEBUG) && !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#    include <pyconfig.h>
     /* sanity-check: Py_LIMITED_API will cause crashes if any of these
        are also defined.  Normally, the Python file PC/pyconfig.h does not
        cause any of these to be defined, with the exception that _DEBUG
        causes Py_DEBUG.  Double-check that. */
#    ifdef Py_LIMITED_API
#      if defined(Py_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_DEBUG, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_TRACE_REFS)
#        error "pyconfig.h unexpectedly defines Py_TRACE_REFS, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_REF_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_REF_DEBUG, but Py_LIMITED_API is set"
#      endif
#    endif
#  else
#    include <pyconfig.h>
#    if !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#  endif
#endif

#include <Python.h>
#ifdef __cplusplus
extern "C" {
#endif
#include <stddef.h>

/* This part is from file 'cffi/parse_c_type.h'.  It is copied at the
   beginning of C sources generated by CFFI's ffi.set_source(). */

typedef void *_cffi_opcode_t;

#define _CFFI_OP(opcode, arg)   (_cffi_opcode_t)(opcode | (((uintptr_t)(arg)) << 8))
#define _CFFI_GETOP(cffi_opcode)    ((unsigned char)(uintptr_t)cffi_opcode)
#define _CFFI_GETARG(cffi_opcode)   (((intptr_t)cffi_opcode) >> 8)

#define _CFFI_OP_PRIMITIVE       1
#define _CFFI_OP_POINTER         3
#define _CFFI_OP_ARRAY           5
#define _CFFI_OP_OPEN_ARRAY      7
#define _CFFI_OP_STRUCT_UNION    9
#define _CFFI_OP_ENUM           11
#define _CFFI_OP_FUNCTION       13
#define _CFFI_OP_FUNCTION_END   15
#define _CFFI_OP_NOOP           17
#define _CFFI_OP_BITFIELD       19
#define _CFFI_OP_TYPENAME       21
#define _CFFI_OP_CPYTHON_BLTN_V 23   // varargs
#define _CFFI_OP_CPYTHON_BLTN_N 25   // noargs
#define _CFFI_OP_CPYTHON_BLTN_O 27   // O  (i.e. a single arg)
#define _CFFI_OP_CONSTANT       29
#define _CFFI_OP_CONSTANT_INT   31
#define _CFFI_OP_GLOBAL_VAR     33
#define _CFFI_OP_DLOPEN_FUNC    35
#define _CFFI_OP_DLOPEN_CONST   37
#define _CFFI_OP_GLOBAL_VAR_F   39
#define _CFFI_OP_EXTERN_PYTHON  41

#define _CFFI_PRIM_VOID          0
#define _CFFI_PRIM_BOOL          1
#define _CFFI_PRIM_CHAR          2
#define _CFFI_PRIM_SCHAR         3
#define _CFFI_PRIM_UCHAR         4
#define _CFFI_PRIM_SHORT         5
#define _CFFI_PRIM_USHORT        6
#define _CFFI_PRIM_INT           7
#define _CFFI_PRIM_UINT          8
#define _CFFI_PRIM_LONG          9
#define _CFFI_PRIM_ULONG        10
#define _CFFI_PRIM_LONGLONG     11
#define _CFFI_PRIM_ULONGLONG    12
#define _CFFI_PRIM_FLOAT        13
#define _CFFI_PRIM_DOUBLE       14
#define _CFFI_PRIM_LONGDOUBLE   15

#define _CFFI_PRIM_WCHAR        16
#define _CFFI_PRIM_INT8         17
#define _CFFI_PRIM_UINT8        18
#define _CFFI_PRIM_INT16        19
#define _CFFI_PRIM_UINT16       20
#define _CFFI_PRIM_INT32        21
#define _CFFI_PRIM_UINT32       22
#define _CFFI_PRIM_INT64        23
#define _CFFI_PRIM_UINT64       24
#define _CFFI_PRIM_INTPTR       25
#define _CFFI_PRIM_UINTPTR      26
#define _CFFI_PRIM_PTRDIFF      27
#define _CFFI_PRIM_SIZE         28
#define _CFFI_PRIM_SSIZE        29
#define _CFFI_PRIM_INT_LEAST8   30
#define _CFFI_PRIM_UINT_LEAST8  31
#define _CFFI_PRIM_INT_LEAST16  32
#define _CFFI_PRIM_UINT_LEAST16 33
#define _CFFI_PRIM_INT_LEAST32  34
#define _CFFI_PRIM_UINT_LEAST32 35
#define _CFFI_PRIM_INT_LEAST64  36
#define _CFFI_PRIM_UINT_LEAST64 37
#define _CFFI_PRIM_INT_FAST8    38
#define _CFFI_PRIM_UINT_FAST8   39
#define _CFFI_PRIM_INT_FAST16   40
#define _CFFI_PRIM_UINT_FAST16  41
#define _CFFI_PRIM_INT_FAST32   42
#define _CFFI_PRIM_UINT_FAST32  43
#define _CFFI_PRIM_INT_FAST64   44
#define _CFFI_PRIM_UINT_FAST64  45
#define _CFFI_PRIM_INTMAX       46
#define _CFFI_PRIM_UINTMAX      47
#define _CFFI_PRIM_FLOATCOMPLEX 48
#define _CFFI_PRIM_DOUBLECOMPLEX 49
#define _CFFI_PRIM_CHAR16       50
#define _CFFI_PRIM_CHAR32       51

#define _CFFI__NUM_PRIM         52
#define _CFFI__UNKNOWN_PRIM           (-1)
#define _CFFI__UNKNOWN_FLOAT_PRIM     (-2)
#define _CFFI__UNKNOWN_LONG_DOUBLE    (-3)

#define _CFFI__IO_FILE_STRUCT         (-1)


struct _cffi_global_s {
    const char *name;
    void *address;
    _cffi_opcode_t type_op;
    void *size_or_direct_fn;  // OP_GLOBAL_VAR: size, or 0 if unknown
                              // OP_CPYTHON_BLTN_*: addr of direct function
};

struct _cffi_getconst_s {
    unsigned long long value;
    const struct _cffi_type_context_s *ctx;
    int gindex;
};

struct _cffi_struct_union_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_STRUCT_UNION
    int flags;               // _CFFI_F_* flags below
    size_t size;
    int alignment;
    int first_field_index;   // -> _cffi_fields array
    int num_fields;
};
#define _CFFI_F_UNION         0x01   // is a union, not a struct
#define _CFFI_F_CHECK_FIELDS  0x02   // complain if fields are not in the
                                     // "standard layout" or if some are missing
#define _CFFI_F_PACKED        0x04   // for CHECK_FIELDS, assume a packed struct
#define _CFFI_F_EXTERNAL      0x08   // in some other ffi.include()
#define _CFFI_F_OPAQUE        0x10   // opaque

struct _cffi_field_s {
    const char *name;
    size_t field_offset;
    size_t field_size;
    _cffi_opcode_t field_type_op;
};

struct _cffi_enum_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_ENUM
    int type_prim;           // _CFFI_PRIM_xxx
    const char *enumerators; // comma-delimited string
};

struct _cffi_typename_s {
    const char *name;
    int type_index;   /* if opaque, points to a possibly artificial
                         OP_STRUCT which is itself opaque */
};

struct _cffi_type_context_s {
    _cffi_opcode_t *types;
    const struct _cffi_global_s *globals;
    const struct _cffi_field_s *fields;
    const struct _cffi_struct_union_s *struct_unions;
    const struct _cffi_enum_s *enums;
    const struct _cffi_typename_s *typenames;
    int num_globals;
    int num_struct_unions;
    int num_enums;
    int num_typenames;
    const char *const *includes;
    int num_types;
    int flags;      /* future extension */
};

struct _cffi_parse_info_s {
    const struct _cffi_type_context_s *ctx;
    _cffi_opcode_t *output;
    unsigned int output_size;
    size_t error_location;
    const char *error_message;
};

struct _cffi_externpy_s {
    const char *name;
    size_t size_of_result;
    void *reserved1, *reserved2;
};

#ifdef _CFFI_INTERNAL
static int parse_c_type(struct _cffi_parse_info_s *info, const char *input);
static int search_in_globals(const struct _cffi_type_context_s *ctx,
                             const char *search, size_t search_len);
static int search_in_struct_unions(const struct _cffi_type_context_s *ctx,
                                   const char *search, size_t search_len);
#endif

/* this block of #ifs should be kept exactly identical between
   c/_cffi_backend.c, cffi/vengine_cpy.py, cffi/vengine_gen.py
   and cffi/_cffi_include.h */
#if defined(_MSC_VER)
# include <malloc.h>   /* for alloca() */
# if _MSC_VER < 1600   /* MSVC < 2010 */
   typedef __int8 int8_t;
   typedef __int16 int16_t;
   typedef __int32 int32_t;
   typedef __int64 int64_t;
   typedef unsigned __int8 uint8_t;
   typedef unsigned __int16 uint16_t;
   typedef unsigned __int32 uint32_t;
   typedef unsigned __int64 uint64_t;
   typedef __int8 int_least8_t;
   typedef __int16 int_least16_t;
   typedef __int32 int_least32_t;
   typedef __int64 int_least64_t;
   typedef unsigned __int8 uint_least8_t;
   typedef unsigned __int16 uint_least16_t;
   typedef unsigned __int32 uint_least32_t;
   typedef unsigned __int64 uint_least64_t;
   typedef __int8 int_fast8_t;
   typedef __int16 int_fast16_t;
   typedef __int32 int_fast32_t;
   typedef __int64 int_fast64_t;
   typedef unsigned __int8 uint_fast8_t;
   typedef unsigned __int16 uint_fast16_t;
   typedef unsigned __int32 uint_fast32_t;
   typedef unsigned __int64 uint_fast64_t;
   typedef __int64 intmax_t;
   typedef unsigned __int64 uintmax_t;
# else
#  include <stdint.h>
# endif
# if _MSC_VER < 1800   /* MSVC < 2013 */
#  ifndef __cplusplus
    typedef unsigned char _Bool;
#  endif
# endif
#else
# include <stdint.h>
# if (defined (__SVR4) && defined (__sun)) || defined(_AIX) || defined(__hpux)
#  include <alloca.h>
# endif
#endif

#ifdef __GNUC__
# define _CFFI_UNUSED_FN  __attribute__((unused))
#else
# define _CFFI_UNUSED_FN  /* nothing */
#endif

#ifdef __cplusplus
# ifndef _Bool
   typedef bool _Bool;   /* semi-hackish: C++ has no _Bool; bool is builtin */
# endif
#endif

/**********  CPython-specific section  **********/
#ifndef PYPY_VERSION


#if PY_MAJOR_VERSION >= 3
# define PyInt_FromLong PyLong_FromLong
#endif

#define _cffi_from_c_double PyFloat_FromDouble
#define _cffi_from_c_float PyFloat_FromDouble
#define _cffi_from_c_long PyInt_FromLong
#define _cffi_from_c_ulong PyLong_FromUnsignedLong
#define _cffi_from_c_longlong PyLong_FromLongLong
#define _cffi_from_c_ulonglong PyLong_FromUnsignedLongLong
#define _cffi_from_c__Bool PyBool_FromLong

#define _cffi_to_c_double PyFloat_AsDouble
#define _cffi_to_c_float PyFloat_AsDouble

#define _cffi_from_c_int(x, type)                                        \
    (((type)-1) > 0 ? /* unsigned */                                     \
        (sizeof(type) < sizeof(long) ?                                   \
            PyInt_FromLong((long)x) :                                    \
         sizeof(type) == sizeof(long) ?                                  \
            PyLong_FromUnsignedLong((unsigned long)x) :                  \
            PyLong_FromUnsignedLongLong((unsigned long long)x)) :        \
        (sizeof(type) <= sizeof(long) ?                                  \
            PyInt_FromLong((long)x) :                                    \
            PyLong_FromLongLong((long long)x)))

#define _cffi_to_c_int(o, type)                                          \
    ((type)(                                                             \
     sizeof(type) == 1 ? (((type)-1) > 0 ? (type)_cffi_to_c_u8(o)        \
                                         : (type)_cffi_to_c_i8(o)) :     \
     sizeof(type) == 2 ? (((type)-1) > 0 ? (type)_cffi_to_c_u16(o)       \
                                         : (type)_cffi_to_c_i16(o)) :    \
     sizeof(type) == 4 ? (((type)-1) > 0 ? (type)_cffi_to_c_u32(o)       \
                                         : (type)_cffi_to_c_i32(o)) :    \
     sizeof(type) == 8 ? (((type)-1) > 0 ? (type)_cffi_to_c_u64(o)       \
                                         : (type)_cffi_to_c_i64(o)) :    \
     (Py_FatalError("unsupported size for type " #type), (type)0)))

#define _cffi_to_c_i8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[1])
#define _cffi_to_c_u8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[2])
#define _cffi_to_c_i16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[3])
#define _cffi_to_c_u16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[4])
#define _cffi_to_c_i32                                                   \
                 ((int(*)(PyObject *))_cffi_exports[5])
#define _cffi_to_c_u32                                                   \
                 ((unsigned int(*)(PyObject *))_cffi_exports[6])
#define _cffi_to_c_i64                                                   \
                 ((long long(*)(PyObject *))_cffi_exports[7])
#define _cffi_to_c_u64                                                   \
                 ((unsigned long long(*)(PyObject *))_cffi_exports[8])
#define _cffi_to_c_char                                                  \
                 ((int(*)(PyObject *))_cffi_exports[9])
#define _cffi_from_c_pointer                                             \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[10])
#define _cffi_to_c_pointer                                               \
    ((char *(*)(PyObject *, struct _cffi_ctypedescr *))_cffi_exports[11])
#define _cffi_get_struct_layout                                          \
    not used any more
#define _cffi_restore_errno                                              \
    ((void(*)(void))_cffi_exports[13])
#define _cffi_save_errno                                                 \
    ((void(*)(void))_cffi_exports[14])
#define _cffi_from_c_char                                                \
    ((PyObject *(*)(char))_cffi_exports[15])
#define _cffi_from_c_deref                                               \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[16])
#define _cffi_to_c                                                       \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[17])
#define _cffi_from_c_struct                                              \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[18])
#define _cffi_to_c_wchar_t                                               \
    ((_cffi_wchar_t(*)(PyObject *))_cffi_exports[19])
#define _cffi_from_c_wchar_t                                             \
    ((PyObject *(*)(_cffi_wchar_t))_cffi_exports[20])
#define _cffi_to_c_long_double                                           \
    ((long double(*)(PyObject *))_cffi_exports[21])
#define _cffi_to_c__Bool                                                 \
    ((_Bool(*)(PyObject *))_cffi_exports[22])
#define _cffi_prepare_pointer_call_argument                              \
    ((Py_ssize_t(*)(struct _cffi_ctypedescr *,                           \
                    PyObject *, char **))_cffi_exports[23])
#define _cffi_convert_array_from_object                                  \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[24])
#define _CFFI_CPIDX  25
#define _cffi_call_python                                                \
    ((void(*)(struct _cffi_externpy_s *, char *))_cffi_exports[_CFFI_CPIDX])
#define _cffi_to_c_wchar3216_t                                           \
    ((int(*)(PyObject *))_cffi_exports[26])
#define _cffi_from_c_wchar3216_t                                         \
    ((PyObject *(*)(int))_cffi_exports[27])
#define _CFFI_NUM_EXPORTS 28

struct _cffi_ctypedescr;

static void *_cffi_exports[_CFFI_NUM_EXPORTS];

#define _cffi_type(index)   (                           \
    assert((((uintptr_t)_cffi_types[index]) & 1) == 0), \
    (struct _cffi_ctypedescr *)_cffi_types[index])

static PyObject *_cffi_init(const char *module_name, Py_ssize_t version,
                            const struct _cffi_type_context_s *ctx)
{
    PyObject *module, *o_arg, *new_module;
    void *raw[] = {
        (void *)module_name,
        (void *)version,
        (void *)_cffi_exports,
        (void *)ctx,
    };

    module = PyImport_ImportModule("_cffi_backend");
    if (module == NULL)
        goto failure;

    o_arg = PyLong_FromVoidPtr((void *)raw);
    if (o_arg == NULL)
        goto failure;

    new_module = PyObject_CallMethod(
        module, (char *)"_init_cffi_1_0_external_module", (char *)"O", o_arg);

    Py_DECREF(o_arg);
    Py_DECREF(module);
    return new_module;

  failure:
    Py_XDECREF(module);
    return NULL;
}


#ifdef HAVE_WCHAR_H
typedef wchar_t _cffi_wchar_t;
#else
typedef uint16_t _cffi_wchar_t;   /* same random pick as _cffi_backend.c */
#endif

_CFFI_UNUSED_FN static uint16_t _cffi_to_c_char16_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return (uint16_t)_cffi_to_c_wchar_t(o);
    else
        return (uint16_t)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char16_t(uint16_t x)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

_CFFI_UNUSED_FN static int _cffi_to_c_char32_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return (int)_cffi_to_c_wchar_t(o);
    else
        return (int)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char32_t(unsigned int x)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

union _cffi_union_alignment_u {
    unsigned char m_char;
    unsigned short m_short;
    unsigned int m_int;
    unsigned long m_long;
    unsigned long long m_longlong;
    float m_float;
    double m_double;
    long double m_longdouble;
};

struct _cffi_freeme_s {
    struct _cffi_freeme_s *next;
    union _cffi_union_alignment_u alignment;
};

_CFFI_UNUSED_FN static int
_cffi_convert_array_argument(struct _cffi_ctypedescr *ctptr, PyObject *arg,
                             char **output_data, Py_ssize_t datasize,
                             struct _cffi_freeme_s **freeme)
{
    char *p;
    if (datasize < 0)
        return -1;

    p = *output_data;
    if (p == NULL) {
        struct _cffi_freeme_s *fp = (struct _cffi_freeme_s *)PyObject_Malloc(
            offsetof(struct _cffi_freeme_s, alignment) + (size_t)datasize);
        if (fp == NULL)
            return -1;
        fp->next = *freeme;
        *freeme = fp;
        p = *output_data = (char *)&fp->alignment;
    }
    memset((void *)p, 0, (size_t)datasize);
    return _cffi_convert_array_from_object(p, ctptr, arg);
}

_CFFI_UNUSED_FN static void
_cffi_free_array_arguments(struct _cffi_freeme_s *freeme)
{
    do {
        void *p = (void *)freeme;
        freeme = freeme->next;
        PyObject_Free(p);
    } while (freeme != NULL);
}

/**********  end CPython-specific section  **********/
#else
_CFFI_UNUSED_FN
static void (*_cffi_call_python_org)(struct _cffi_externpy_s *, char *);
# define _cffi_call_python  _cffi_call_python_org
#endif


#define _cffi_array_len(array)   (sizeof(array) / sizeof((array)[0]))

#define _cffi_prim_int(size, sign)                                      \
    ((size) == 1 ? ((sign) ? _CFFI_PRIM_INT8  : _CFFI_PRIM_UINT8)  :    \
     (size) == 2 ? ((sign) ? _CFFI_PRIM_INT16 : _CFFI_PRIM_UINT16) :    \
     (size) == 4 ? ((sign) ? _CFFI_PRIM_INT32 : _CFFI_PRIM_UINT32) :    \
     (size) == 8 ? ((sign) ? _CFFI_PRIM_INT64 : _CFFI_PRIM_UINT64) :    \
     _CFFI__UNKNOWN_PRIM)

#define _cffi_prim_float(size)                                          \
    ((size) == sizeof(float) ? _CFFI_PRIM_FLOAT :                       \
     (size) == sizeof(double) ? _CFFI_PRIM_DOUBLE :                     \
     (size) == sizeof(long double) ? _CFFI__UNKNOWN_LONG_DOUBLE :       \
     _CFFI__UNKNOWN_FLOAT_PRIM)

#define _cffi_check_int(got, got_nonpos, expected)      \
    ((got_nonpos) == (expected <= 0) &&                 \
     (got) == (unsigned long long)expected)

#ifdef MS_WIN32
# define _cffi_stdcall  __stdcall
#else
# define _cffi_stdcall  /* nothing */
#endif

#ifdef __cplusplus
}
#endif

/************************************************************/

void f_ini_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[52]*x[0] - y[44] + u[22] + 1;

}
void g_ini_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -y[1]*(p[1] + p[33]) + y[0]*p[0] + y[0]*p[32] - y[3]*(p[3] + p[35]) + y[2]*p[2] + y[2]*p[34] - y[5]*p[5] + y[4]*p[4] - y[7]*p[7] + y[6]*p[6] + y[9]*p[1] - y[8]*p[0] + y[11]*p[3] - y[10]*p[2] + y[13]*p[5] - y[12]*p[4] + y[15]*p[7] - y[14]*p[6] + y[17]*p[33] - y[16]*p[32] + y[19]*p[35] - y[18]*p[34] - y[32];
out[1] = y[1]*p[0] + y[1]*p[32] + y[0]*(p[1] + p[33]) + y[3]*p[2] + y[3]*p[34] + y[2]*(p[3] + p[35]) + y[5]*p[4] + y[4]*p[5] + y[7]*p[6] + y[6]*p[7] - y[9]*p[0] - y[8]*p[1] - y[11]*p[2] - y[10]*p[3] - y[13]*p[4] - y[12]*p[5] - y[15]*p[6] - y[14]*p[7] - y[17]*p[32] - y[16]*p[33] - y[19]*p[34] - y[18]*p[35] - y[39];
out[2] = -y[1]*(p[9] + p[37]) + y[0]*p[8] + y[0]*p[36] - y[3]*(p[11] + p[39]) + y[2]*p[10] + y[2]*p[38] - y[5]*p[13] + y[4]*p[12] - y[7]*p[15] + y[6]*p[14] + y[9]*p[9] - y[8]*p[8] + y[11]*p[11] - y[10]*p[10] + y[13]*p[13] - y[12]*p[12] + y[15]*p[15] - y[14]*p[14] + y[17]*p[37] - y[16]*p[36] + y[19]*p[39] - y[18]*p[38] - y[33];
out[3] = y[1]*p[8] + y[1]*p[36] + y[0]*(p[9] + p[37]) + y[3]*p[10] + y[3]*p[38] + y[2]*(p[11] + p[39]) + y[5]*p[12] + y[4]*p[13] + y[7]*p[14] + y[6]*p[15] - y[9]*p[8] - y[8]*p[9] - y[11]*p[10] - y[10]*p[11] - y[13]*p[12] - y[12]*p[13] - y[15]*p[14] - y[14]*p[15] - y[17]*p[36] - y[16]*p[37] - y[19]*p[38] - y[18]*p[39] - y[40];
out[4] = -y[1]*p[17] + y[0]*p[16] - y[3]*p[19] + y[2]*p[18] - y[5]*p[21] + y[4]*p[20] - y[7]*p[23] + y[6]*p[22] + y[9]*p[17] - y[8]*p[16] + y[11]*p[19] - y[10]*p[18] + y[13]*p[21] - y[12]*p[20] + y[15]*p[23] - y[14]*p[22] - y[34];
out[5] = y[1]*p[16] + y[0]*p[17] + y[3]*p[18] + y[2]*p[19] + y[5]*p[20] + y[4]*p[21] + y[7]*p[22] + y[6]*p[23] - y[9]*p[16] - y[8]*p[17] - y[11]*p[18] - y[10]*p[19] - y[13]*p[20] - y[12]*p[21] - y[15]*p[22] - y[14]*p[23] - y[41];
out[6] = -y[1]*p[25] + y[0]*p[24] - y[3]*p[27] + y[2]*p[26] - y[5]*p[29] + y[4]*p[28] - y[7]*p[31] + y[6]*p[30] + y[9]*p[25] - y[8]*p[24] + y[11]*p[27] - y[10]*p[26] + y[13]*p[29] - y[12]*p[28] + y[15]*p[31] - y[14]*p[30] - y[35];
out[7] = y[1]*p[24] + y[0]*p[25] + y[3]*p[26] + y[2]*p[27] + y[5]*p[28] + y[4]*p[29] + y[7]*p[30] + y[6]*p[31] - y[9]*p[24] - y[8]*p[25] - y[11]*p[26] - y[10]*p[27] - y[13]*p[28] - y[12]*p[29] - y[15]*p[30] - y[14]*p[31] - y[42];
out[8] = y[1]*p[1] - y[0]*p[0] + y[3]*p[3] - y[2]*p[2] + y[5]*p[5] - y[4]*p[4] + y[7]*p[7] - y[6]*p[6] - y[9]*p[1] + y[8]*p[0] - y[11]*p[3] + y[10]*p[2] - y[13]*p[5] + y[12]*p[4] - y[15]*p[7] + y[14]*p[6] - y[24];
out[9] = -y[1]*p[0] - y[0]*p[1] - y[3]*p[2] - y[2]*p[3] - y[5]*p[4] - y[4]*p[5] - y[7]*p[6] - y[6]*p[7] + y[9]*p[0] + y[8]*p[1] + y[11]*p[2] + y[10]*p[3] + y[13]*p[4] + y[12]*p[5] + y[15]*p[6] + y[14]*p[7] - y[25];
out[10] = y[1]*p[9] - y[0]*p[8] + y[3]*p[11] - y[2]*p[10] + y[5]*p[13] - y[4]*p[12] + y[7]*p[15] - y[6]*p[14] - y[9]*p[9] + y[8]*p[8] - y[11]*p[11] + y[10]*p[10] - y[13]*p[13] + y[12]*p[12] - y[15]*p[15] + y[14]*p[14] - y[26];
out[11] = -y[1]*p[8] - y[0]*p[9] - y[3]*p[10] - y[2]*p[11] - y[5]*p[12] - y[4]*p[13] - y[7]*p[14] - y[6]*p[15] + y[9]*p[8] + y[8]*p[9] + y[11]*p[10] + y[10]*p[11] + y[13]*p[12] + y[12]*p[13] + y[15]*p[14] + y[14]*p[15] - y[27];
out[12] = y[1]*p[17] - y[0]*p[16] + y[3]*p[19] - y[2]*p[18] + y[5]*p[21] - y[4]*p[20] + y[7]*p[23] - y[6]*p[22] - y[9]*p[17] + y[8]*p[16] - y[11]*p[19] + y[10]*p[18] - y[13]*p[21] + y[12]*p[20] - y[15]*p[23] + y[14]*p[22] - y[28];
out[13] = -y[1]*p[16] - y[0]*p[17] - y[3]*p[18] - y[2]*p[19] - y[5]*p[20] - y[4]*p[21] - y[7]*p[22] - y[6]*p[23] + y[9]*p[16] + y[8]*p[17] + y[11]*p[18] + y[10]*p[19] + y[13]*p[20] + y[12]*p[21] + y[15]*p[22] + y[14]*p[23] - y[29];
out[14] = y[1]*p[25] - y[0]*p[24] + y[3]*p[27] - y[2]*p[26] + y[5]*p[29] - y[4]*p[28] + y[7]*p[31] - y[6]*p[30] - y[9]*p[25] + y[8]*p[24] - y[11]*p[27] + y[10]*p[26] - y[13]*p[29] + y[12]*p[28] - y[15]*p[31] + y[14]*p[30] - y[30];
out[15] = -y[1]*p[24] - y[0]*p[25] - y[3]*p[26] - y[2]*p[27] - y[5]*p[28] - y[4]*p[29] - y[7]*p[30] - y[6]*p[31] + y[9]*p[24] + y[8]*p[25] + y[11]*p[26] + y[10]*p[27] + y[13]*p[28] + y[12]*p[29] + y[15]*p[30] + y[14]*p[31] - y[31];
out[16] = y[1]*p[33] - y[0]*p[32] + y[3]*p[35] - y[2]*p[34] - y[17]*p[33] + y[16]*p[32] - y[19]*p[35] + y[18]*p[34];
out[17] = -y[1]*p[32] - y[0]*p[33] - y[3]*p[34] - y[2]*p[35] + y[17]*p[32] + y[16]*p[33] + y[19]*p[34] + y[18]*p[35];
out[18] = y[1]*p[37] - y[0]*p[36] + y[3]*p[39] - y[2]*p[38] - y[17]*p[37] + y[16]*p[36] - y[19]*p[39] + y[18]*p[38];
out[19] = -y[1]*p[36] - y[0]*p[37] - y[3]*p[38] - y[2]*p[39] + y[17]*p[36] + y[16]*p[37] + y[19]*p[38] + y[18]*p[39];
out[20] = 0;
out[21] = 0;
out[22] = 0;
out[23] = 0;
out[24] = pow(y[9], 2)*u[2] - 2*y[9]*y[15]*u[2] + y[9]*y[25] + pow(y[8], 2)*u[2] - 2*y[8]*y[14]*u[2] + y[8]*y[24] + pow(y[15], 2)*u[2] - y[15]*y[25] + pow(y[14], 2)*u[2] - y[14]*y[24] + u[0];
out[25] = pow(y[11], 2)*u[6] - 2*y[11]*y[15]*u[6] + y[11]*y[27] + pow(y[10], 2)*u[6] - 2*y[10]*y[14]*u[6] + y[10]*y[26] + pow(y[15], 2)*u[6] - y[15]*y[27] + pow(y[14], 2)*u[6] - y[14]*y[26] + u[4];
out[26] = pow(y[13], 2)*u[10] - 2*y[13]*y[15]*u[10] + y[13]*y[29] + pow(y[12], 2)*u[10] - 2*y[12]*y[14]*u[10] + y[12]*y[28] + pow(y[15], 2)*u[10] - y[15]*y[29] + pow(y[14], 2)*u[10] - y[14]*y[28] + u[8];
out[27] = -1.0*pow(y[9], 2)*u[3] + 2.0*y[9]*y[15]*u[3] + y[9]*y[24] - 1.0*pow(y[8], 2)*u[3] + 2.0*y[8]*y[14]*u[3] - y[8]*y[25] - 1.0*pow(y[15], 2)*u[3] - y[15]*y[24] - 1.0*pow(y[14], 2)*u[3] + y[14]*y[25] + u[1];
out[28] = -1.0*pow(y[11], 2)*u[7] + 2.0*y[11]*y[15]*u[7] + y[11]*y[26] - 1.0*pow(y[10], 2)*u[7] + 2.0*y[10]*y[14]*u[7] - y[10]*y[27] - 1.0*pow(y[15], 2)*u[7] - y[15]*y[26] - 1.0*pow(y[14], 2)*u[7] + y[14]*y[27] + u[5];
out[29] = -1.0*pow(y[13], 2)*u[11] + 2.0*y[13]*y[15]*u[11] + y[13]*y[28] - 1.0*pow(y[12], 2)*u[11] + 2.0*y[12]*y[14]*u[11] - y[12]*y[29] - 1.0*pow(y[15], 2)*u[11] - y[15]*y[28] - 1.0*pow(y[14], 2)*u[11] + y[14]*y[29] + u[9];
out[30] = y[24] + y[26] + y[28] + y[30];
out[31] = y[25] + y[27] + y[29] + y[31];
out[32] = -p[41]*y[32] - y[0] + 1.0*p[40]*y[39] + 0.40824829046386307*u[13]*u[12]*cos(u[17] + u[18]) + y[36];
out[33] = -p[41]*y[33] - y[2] + 1.0*p[40]*y[40] + 0.40824829046386307*u[14]*u[12]*cos(u[17] + u[19] - 2.0943951023931953) + y[36];
out[34] = -p[41]*y[34] - y[4] + 1.0*p[40]*y[41] + 0.40824829046386307*u[15]*u[12]*cos(u[17] + u[20] - 4.1887902047863905) + y[36];
out[35] = -p[43]*y[35] - y[6] + 1.0*p[42]*y[42] + 0.40824829046386307*u[16]*u[12]*cos(u[21]) + y[36];
out[36] = p[45]*y[36]/(pow(p[45], 2) + 1.0*pow(p[44], 2)) + 1.0*p[44]*y[43]/(pow(p[45], 2) + 1.0*pow(p[44], 2)) + y[32] + y[33] + y[34] + y[35];
out[37] = -1.0*p[41]*y[39] - 1.0*y[1] - 1.0*p[40]*y[32] + 0.40824829046386307*u[13]*u[12]*sin(u[17] + u[18]) + 1.0*y[43];
out[38] = -1.0*p[41]*y[40] - 1.0*y[3] - 1.0*p[40]*y[33] + 0.40824829046386307*u[14]*u[12]*sin(u[17] + u[19] - 2.0943951023931953) + 1.0*y[43];
out[39] = -1.0*p[41]*y[41] - 1.0*y[5] - 1.0*p[40]*y[34] + 0.40824829046386307*u[15]*u[12]*sin(u[17] + u[20] - 4.1887902047863905) + 1.0*y[43];
out[40] = -1.0*p[43]*y[42] - 1.0*y[7] - 1.0*p[42]*y[35] + 0.40824829046386307*u[16]*u[12]*sin(u[21]) + 1.0*y[43];
out[41] = 1.0*p[45]*y[43]/(pow(p[45], 2) + 1.0*pow(p[44], 2)) - 1.0*p[44]*y[36]/(pow(p[45], 2) + 1.0*pow(p[44], 2)) + 1.0*y[39] + 1.0*y[40] + 1.0*y[41] + 1.0*y[42];
out[42] = 4*p[47] + p[48]*sqrt(pow(y[39], 2) + pow(y[32], 2) + 9.9999999999999995e-7) + p[48]*sqrt(pow(y[40], 2) + pow(y[33], 2) + 9.9999999999999995e-7) + p[48]*sqrt(pow(y[41], 2) + pow(y[34], 2) + 9.9999999999999995e-7) + p[48]*sqrt(pow(y[42], 2) + pow(y[35], 2) + 9.9999999999999995e-7) + p[49]*(pow(y[39], 2) + pow(y[32], 2) + 9.9999999999999995e-7) + p[49]*(pow(y[40], 2) + pow(y[33], 2) + 9.9999999999999995e-7) + p[49]*(pow(y[41], 2) + pow(y[34], 2) + 9.9999999999999995e-7) + p[49]*(pow(y[42], 2) + pow(y[35], 2) + 9.9999999999999995e-7) + 1.0*y[1]*y[39] + y[0]*y[32] + 1.0*y[3]*y[40] + y[2]*y[33] + 1.0*y[5]*y[41] + y[4]*y[34] + 1.0*y[7]*y[41] + y[6]*y[34] - y[37];
out[43] = -y[38] + y[37]/u[12];
out[44] = 1.0 - y[44];
out[45] = p[51]*x[0] + p[50]*(1 - y[44]) - y[45];

}
void f_run_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[52]*x[0] - y[44] + u[22] + 1;

}
void g_run_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -y[1]*(p[1] + p[33]) + y[0]*p[0] + y[0]*p[32] - y[3]*(p[3] + p[35]) + y[2]*p[2] + y[2]*p[34] - y[5]*p[5] + y[4]*p[4] - y[7]*p[7] + y[6]*p[6] + y[9]*p[1] - y[8]*p[0] + y[11]*p[3] - y[10]*p[2] + y[13]*p[5] - y[12]*p[4] + y[15]*p[7] - y[14]*p[6] + y[17]*p[33] - y[16]*p[32] + y[19]*p[35] - y[18]*p[34] - y[32];
out[1] = y[1]*p[0] + y[1]*p[32] + y[0]*(p[1] + p[33]) + y[3]*p[2] + y[3]*p[34] + y[2]*(p[3] + p[35]) + y[5]*p[4] + y[4]*p[5] + y[7]*p[6] + y[6]*p[7] - y[9]*p[0] - y[8]*p[1] - y[11]*p[2] - y[10]*p[3] - y[13]*p[4] - y[12]*p[5] - y[15]*p[6] - y[14]*p[7] - y[17]*p[32] - y[16]*p[33] - y[19]*p[34] - y[18]*p[35] - y[39];
out[2] = -y[1]*(p[9] + p[37]) + y[0]*p[8] + y[0]*p[36] - y[3]*(p[11] + p[39]) + y[2]*p[10] + y[2]*p[38] - y[5]*p[13] + y[4]*p[12] - y[7]*p[15] + y[6]*p[14] + y[9]*p[9] - y[8]*p[8] + y[11]*p[11] - y[10]*p[10] + y[13]*p[13] - y[12]*p[12] + y[15]*p[15] - y[14]*p[14] + y[17]*p[37] - y[16]*p[36] + y[19]*p[39] - y[18]*p[38] - y[33];
out[3] = y[1]*p[8] + y[1]*p[36] + y[0]*(p[9] + p[37]) + y[3]*p[10] + y[3]*p[38] + y[2]*(p[11] + p[39]) + y[5]*p[12] + y[4]*p[13] + y[7]*p[14] + y[6]*p[15] - y[9]*p[8] - y[8]*p[9] - y[11]*p[10] - y[10]*p[11] - y[13]*p[12] - y[12]*p[13] - y[15]*p[14] - y[14]*p[15] - y[17]*p[36] - y[16]*p[37] - y[19]*p[38] - y[18]*p[39] - y[40];
out[4] = -y[1]*p[17] + y[0]*p[16] - y[3]*p[19] + y[2]*p[18] - y[5]*p[21] + y[4]*p[20] - y[7]*p[23] + y[6]*p[22] + y[9]*p[17] - y[8]*p[16] + y[11]*p[19] - y[10]*p[18] + y[13]*p[21] - y[12]*p[20] + y[15]*p[23] - y[14]*p[22] - y[34];
out[5] = y[1]*p[16] + y[0]*p[17] + y[3]*p[18] + y[2]*p[19] + y[5]*p[20] + y[4]*p[21] + y[7]*p[22] + y[6]*p[23] - y[9]*p[16] - y[8]*p[17] - y[11]*p[18] - y[10]*p[19] - y[13]*p[20] - y[12]*p[21] - y[15]*p[22] - y[14]*p[23] - y[41];
out[6] = -y[1]*p[25] + y[0]*p[24] - y[3]*p[27] + y[2]*p[26] - y[5]*p[29] + y[4]*p[28] - y[7]*p[31] + y[6]*p[30] + y[9]*p[25] - y[8]*p[24] + y[11]*p[27] - y[10]*p[26] + y[13]*p[29] - y[12]*p[28] + y[15]*p[31] - y[14]*p[30] - y[35];
out[7] = y[1]*p[24] + y[0]*p[25] + y[3]*p[26] + y[2]*p[27] + y[5]*p[28] + y[4]*p[29] + y[7]*p[30] + y[6]*p[31] - y[9]*p[24] - y[8]*p[25] - y[11]*p[26] - y[10]*p[27] - y[13]*p[28] - y[12]*p[29] - y[15]*p[30] - y[14]*p[31] - y[42];
out[8] = y[1]*p[1] - y[0]*p[0] + y[3]*p[3] - y[2]*p[2] + y[5]*p[5] - y[4]*p[4] + y[7]*p[7] - y[6]*p[6] - y[9]*p[1] + y[8]*p[0] - y[11]*p[3] + y[10]*p[2] - y[13]*p[5] + y[12]*p[4] - y[15]*p[7] + y[14]*p[6] - y[24];
out[9] = -y[1]*p[0] - y[0]*p[1] - y[3]*p[2] - y[2]*p[3] - y[5]*p[4] - y[4]*p[5] - y[7]*p[6] - y[6]*p[7] + y[9]*p[0] + y[8]*p[1] + y[11]*p[2] + y[10]*p[3] + y[13]*p[4] + y[12]*p[5] + y[15]*p[6] + y[14]*p[7] - y[25];
out[10] = y[1]*p[9] - y[0]*p[8] + y[3]*p[11] - y[2]*p[10] + y[5]*p[13] - y[4]*p[12] + y[7]*p[15] - y[6]*p[14] - y[9]*p[9] + y[8]*p[8] - y[11]*p[11] + y[10]*p[10] - y[13]*p[13] + y[12]*p[12] - y[15]*p[15] + y[14]*p[14] - y[26];
out[11] = -y[1]*p[8] - y[0]*p[9] - y[3]*p[10] - y[2]*p[11] - y[5]*p[12] - y[4]*p[13] - y[7]*p[14] - y[6]*p[15] + y[9]*p[8] + y[8]*p[9] + y[11]*p[10] + y[10]*p[11] + y[13]*p[12] + y[12]*p[13] + y[15]*p[14] + y[14]*p[15] - y[27];
out[12] = y[1]*p[17] - y[0]*p[16] + y[3]*p[19] - y[2]*p[18] + y[5]*p[21] - y[4]*p[20] + y[7]*p[23] - y[6]*p[22] - y[9]*p[17] + y[8]*p[16] - y[11]*p[19] + y[10]*p[18] - y[13]*p[21] + y[12]*p[20] - y[15]*p[23] + y[14]*p[22] - y[28];
out[13] = -y[1]*p[16] - y[0]*p[17] - y[3]*p[18] - y[2]*p[19] - y[5]*p[20] - y[4]*p[21] - y[7]*p[22] - y[6]*p[23] + y[9]*p[16] + y[8]*p[17] + y[11]*p[18] + y[10]*p[19] + y[13]*p[20] + y[12]*p[21] + y[15]*p[22] + y[14]*p[23] - y[29];
out[14] = y[1]*p[25] - y[0]*p[24] + y[3]*p[27] - y[2]*p[26] + y[5]*p[29] - y[4]*p[28] + y[7]*p[31] - y[6]*p[30] - y[9]*p[25] + y[8]*p[24] - y[11]*p[27] + y[10]*p[26] - y[13]*p[29] + y[12]*p[28] - y[15]*p[31] + y[14]*p[30] - y[30];
out[15] = -y[1]*p[24] - y[0]*p[25] - y[3]*p[26] - y[2]*p[27] - y[5]*p[28] - y[4]*p[29] - y[7]*p[30] - y[6]*p[31] + y[9]*p[24] + y[8]*p[25] + y[11]*p[26] + y[10]*p[27] + y[13]*p[28] + y[12]*p[29] + y[15]*p[30] + y[14]*p[31] - y[31];
out[16] = y[1]*p[33] - y[0]*p[32] + y[3]*p[35] - y[2]*p[34] - y[17]*p[33] + y[16]*p[32] - y[19]*p[35] + y[18]*p[34];
out[17] = -y[1]*p[32] - y[0]*p[33] - y[3]*p[34] - y[2]*p[35] + y[17]*p[32] + y[16]*p[33] + y[19]*p[34] + y[18]*p[35];
out[18] = y[1]*p[37] - y[0]*p[36] + y[3]*p[39] - y[2]*p[38] - y[17]*p[37] + y[16]*p[36] - y[19]*p[39] + y[18]*p[38];
out[19] = -y[1]*p[36] - y[0]*p[37] - y[3]*p[38] - y[2]*p[39] + y[17]*p[36] + y[16]*p[37] + y[19]*p[38] + y[18]*p[39];
out[20] = 0;
out[21] = 0;
out[22] = 0;
out[23] = 0;
out[24] = pow(y[9], 2)*u[2] - 2*y[9]*y[15]*u[2] + y[9]*y[25] + pow(y[8], 2)*u[2] - 2*y[8]*y[14]*u[2] + y[8]*y[24] + pow(y[15], 2)*u[2] - y[15]*y[25] + pow(y[14], 2)*u[2] - y[14]*y[24] + u[0];
out[25] = pow(y[11], 2)*u[6] - 2*y[11]*y[15]*u[6] + y[11]*y[27] + pow(y[10], 2)*u[6] - 2*y[10]*y[14]*u[6] + y[10]*y[26] + pow(y[15], 2)*u[6] - y[15]*y[27] + pow(y[14], 2)*u[6] - y[14]*y[26] + u[4];
out[26] = pow(y[13], 2)*u[10] - 2*y[13]*y[15]*u[10] + y[13]*y[29] + pow(y[12], 2)*u[10] - 2*y[12]*y[14]*u[10] + y[12]*y[28] + pow(y[15], 2)*u[10] - y[15]*y[29] + pow(y[14], 2)*u[10] - y[14]*y[28] + u[8];
out[27] = -1.0*pow(y[9], 2)*u[3] + 2.0*y[9]*y[15]*u[3] + y[9]*y[24] - 1.0*pow(y[8], 2)*u[3] + 2.0*y[8]*y[14]*u[3] - y[8]*y[25] - 1.0*pow(y[15], 2)*u[3] - y[15]*y[24] - 1.0*pow(y[14], 2)*u[3] + y[14]*y[25] + u[1];
out[28] = -1.0*pow(y[11], 2)*u[7] + 2.0*y[11]*y[15]*u[7] + y[11]*y[26] - 1.0*pow(y[10], 2)*u[7] + 2.0*y[10]*y[14]*u[7] - y[10]*y[27] - 1.0*pow(y[15], 2)*u[7] - y[15]*y[26] - 1.0*pow(y[14], 2)*u[7] + y[14]*y[27] + u[5];
out[29] = -1.0*pow(y[13], 2)*u[11] + 2.0*y[13]*y[15]*u[11] + y[13]*y[28] - 1.0*pow(y[12], 2)*u[11] + 2.0*y[12]*y[14]*u[11] - y[12]*y[29] - 1.0*pow(y[15], 2)*u[11] - y[15]*y[28] - 1.0*pow(y[14], 2)*u[11] + y[14]*y[29] + u[9];
out[30] = y[24] + y[26] + y[28] + y[30];
out[31] = y[25] + y[27] + y[29] + y[31];
out[32] = -p[41]*y[32] - y[0] + 1.0*p[40]*y[39] + 0.40824829046386307*u[13]*u[12]*cos(u[17] + u[18]) + y[36];
out[33] = -p[41]*y[33] - y[2] + 1.0*p[40]*y[40] + 0.40824829046386307*u[14]*u[12]*cos(u[17] + u[19] - 2.0943951023931953) + y[36];
out[34] = -p[41]*y[34] - y[4] + 1.0*p[40]*y[41] + 0.40824829046386307*u[15]*u[12]*cos(u[17] + u[20] - 4.1887902047863905) + y[36];
out[35] = -p[43]*y[35] - y[6] + 1.0*p[42]*y[42] + 0.40824829046386307*u[16]*u[12]*cos(u[21]) + y[36];
out[36] = p[45]*y[36]/(pow(p[45], 2) + 1.0*pow(p[44], 2)) + 1.0*p[44]*y[43]/(pow(p[45], 2) + 1.0*pow(p[44], 2)) + y[32] + y[33] + y[34] + y[35];
out[37] = -1.0*p[41]*y[39] - 1.0*y[1] - 1.0*p[40]*y[32] + 0.40824829046386307*u[13]*u[12]*sin(u[17] + u[18]) + 1.0*y[43];
out[38] = -1.0*p[41]*y[40] - 1.0*y[3] - 1.0*p[40]*y[33] + 0.40824829046386307*u[14]*u[12]*sin(u[17] + u[19] - 2.0943951023931953) + 1.0*y[43];
out[39] = -1.0*p[41]*y[41] - 1.0*y[5] - 1.0*p[40]*y[34] + 0.40824829046386307*u[15]*u[12]*sin(u[17] + u[20] - 4.1887902047863905) + 1.0*y[43];
out[40] = -1.0*p[43]*y[42] - 1.0*y[7] - 1.0*p[42]*y[35] + 0.40824829046386307*u[16]*u[12]*sin(u[21]) + 1.0*y[43];
out[41] = 1.0*p[45]*y[43]/(pow(p[45], 2) + 1.0*pow(p[44], 2)) - 1.0*p[44]*y[36]/(pow(p[45], 2) + 1.0*pow(p[44], 2)) + 1.0*y[39] + 1.0*y[40] + 1.0*y[41] + 1.0*y[42];
out[42] = 4*p[47] + p[48]*sqrt(pow(y[39], 2) + pow(y[32], 2) + 9.9999999999999995e-7) + p[48]*sqrt(pow(y[40], 2) + pow(y[33], 2) + 9.9999999999999995e-7) + p[48]*sqrt(pow(y[41], 2) + pow(y[34], 2) + 9.9999999999999995e-7) + p[48]*sqrt(pow(y[42], 2) + pow(y[35], 2) + 9.9999999999999995e-7) + p[49]*(pow(y[39], 2) + pow(y[32], 2) + 9.9999999999999995e-7) + p[49]*(pow(y[40], 2) + pow(y[33], 2) + 9.9999999999999995e-7) + p[49]*(pow(y[41], 2) + pow(y[34], 2) + 9.9999999999999995e-7) + p[49]*(pow(y[42], 2) + pow(y[35], 2) + 9.9999999999999995e-7) + 1.0*y[1]*y[39] + y[0]*y[32] + 1.0*y[3]*y[40] + y[2]*y[33] + 1.0*y[5]*y[41] + y[4]*y[34] + 1.0*y[7]*y[41] + y[6]*y[34] - y[37];
out[43] = -y[38] + y[37]/u[12];
out[44] = 1.0 - y[44];
out[45] = p[51]*x[0] + p[50]*(1 - y[44]) - y[45];

}
void h_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -y[1]*p[1] + y[0]*p[0] - y[3]*p[3] + y[2]*p[2] - y[5]*p[5] + y[4]*p[4] - y[7]*p[7] + y[6]*p[6] + y[9]*p[1] - y[8]*p[0] + y[11]*p[3] - y[10]*p[2] + y[13]*p[5] - y[12]*p[4] + y[15]*p[7] - y[14]*p[6];
out[1] = y[1]*p[0] + y[0]*p[1] + y[3]*p[2] + y[2]*p[3] + y[5]*p[4] + y[4]*p[5] + y[7]*p[6] + y[6]*p[7] - y[9]*p[0] - y[8]*p[1] - y[11]*p[2] - y[10]*p[3] - y[13]*p[4] - y[12]*p[5] - y[15]*p[6] - y[14]*p[7];
out[2] = -y[1]*p[9] + y[0]*p[8] - y[3]*p[11] + y[2]*p[10] - y[5]*p[13] + y[4]*p[12] - y[7]*p[15] + y[6]*p[14] + y[9]*p[9] - y[8]*p[8] + y[11]*p[11] - y[10]*p[10] + y[13]*p[13] - y[12]*p[12] + y[15]*p[15] - y[14]*p[14];
out[3] = y[1]*p[8] + y[0]*p[9] + y[3]*p[10] + y[2]*p[11] + y[5]*p[12] + y[4]*p[13] + y[7]*p[14] + y[6]*p[15] - y[9]*p[8] - y[8]*p[9] - y[11]*p[10] - y[10]*p[11] - y[13]*p[12] - y[12]*p[13] - y[15]*p[14] - y[14]*p[15];
out[4] = -y[1]*p[17] + y[0]*p[16] - y[3]*p[19] + y[2]*p[18] - y[5]*p[21] + y[4]*p[20] - y[7]*p[23] + y[6]*p[22] + y[9]*p[17] - y[8]*p[16] + y[11]*p[19] - y[10]*p[18] + y[13]*p[21] - y[12]*p[20] + y[15]*p[23] - y[14]*p[22];
out[5] = y[1]*p[16] + y[0]*p[17] + y[3]*p[18] + y[2]*p[19] + y[5]*p[20] + y[4]*p[21] + y[7]*p[22] + y[6]*p[23] - y[9]*p[16] - y[8]*p[17] - y[11]*p[18] - y[10]*p[19] - y[13]*p[20] - y[12]*p[21] - y[15]*p[22] - y[14]*p[23];
out[6] = -y[1]*p[25] + y[0]*p[24] - y[3]*p[27] + y[2]*p[26] - y[5]*p[29] + y[4]*p[28] - y[7]*p[31] + y[6]*p[30] + y[9]*p[25] - y[8]*p[24] + y[11]*p[27] - y[10]*p[26] + y[13]*p[29] - y[12]*p[28] + y[15]*p[31] - y[14]*p[30];
out[7] = y[1]*p[24] + y[0]*p[25] + y[3]*p[26] + y[2]*p[27] + y[5]*p[28] + y[4]*p[29] + y[7]*p[30] + y[6]*p[31] - y[9]*p[24] - y[8]*p[25] - y[11]*p[26] - y[10]*p[27] - y[13]*p[28] - y[12]*p[29] - y[15]*p[30] - y[14]*p[31];
out[8] = -y[1]*p[33] + y[0]*p[32] - y[3]*p[35] + y[2]*p[34] + y[17]*p[33] - y[16]*p[32] + y[19]*p[35] - y[18]*p[34];
out[9] = y[1]*p[32] + y[0]*p[33] + y[3]*p[34] + y[2]*p[35] - y[17]*p[32] - y[16]*p[33] - y[19]*p[34] - y[18]*p[35];
out[10] = -y[1]*p[37] + y[0]*p[36] - y[3]*p[39] + y[2]*p[38] + y[17]*p[37] - y[16]*p[36] + y[19]*p[39] - y[18]*p[38];
out[11] = y[1]*p[36] + y[0]*p[37] + y[3]*p[38] + y[2]*p[39] - y[17]*p[36] - y[16]*p[37] - y[19]*p[38] - y[18]*p[39];
out[12] = sqrt(1.0*pow(y[39], 2) + pow(y[32], 2));
out[13] = sqrt(1.0*pow(y[40], 2) + pow(y[33], 2));
out[14] = sqrt(1.0*pow(y[41], 2) + pow(y[34], 2));
out[15] = sqrt(1.0*pow(y[42], 2) + pow(y[35], 2));
out[16] = 0.33333333333333331*y[1]*y[39] - y[1]*(0.16666666666666657*y[40] - 0.28867513459481287*y[33]) - y[1]*(0.16666666666666677*y[41] + 0.28867513459481275*y[34]) + 0.33333333333333331*y[0]*y[32] + y[0]*(-0.28867513459481287*y[40] - 0.16666666666666657*y[33]) + y[0]*(0.28867513459481275*y[41] - 0.16666666666666677*y[34]) + 0.33333333333333326*y[3]*y[40] - 0.16666666666666652*y[3]*y[41] + 0.28867513459481281*y[3]*y[34] + 0.33333333333333326*y[2]*y[33] - 0.28867513459481281*y[2]*y[41] - 0.16666666666666652*y[2]*y[34] - 0.16666666666666652*y[5]*y[40] - 0.28867513459481281*y[5]*y[33] + 0.33333333333333326*y[5]*y[41] + 0.28867513459481281*y[4]*y[40] - 0.16666666666666652*y[4]*y[33] + 0.33333333333333326*y[4]*y[34] + 1.0*y[39]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[39]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]) + 1.0*y[32]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) + 1.0*y[32]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]);
out[17] = 0.33333333333333331*y[1]*y[39] - y[1]*(0.16666666666666677*y[40] + 0.28867513459481275*y[33]) - y[1]*(0.16666666666666657*y[41] - 0.28867513459481287*y[34]) + 0.33333333333333331*y[0]*y[32] + y[0]*(0.28867513459481275*y[40] - 0.16666666666666677*y[33]) + y[0]*(-0.28867513459481287*y[41] - 0.16666666666666657*y[34]) + 0.33333333333333326*y[3]*y[40] - 0.16666666666666652*y[3]*y[41] - 0.28867513459481281*y[3]*y[34] + 0.33333333333333326*y[2]*y[33] + 0.28867513459481281*y[2]*y[41] - 0.16666666666666652*y[2]*y[34] - 0.16666666666666652*y[5]*y[40] + 0.28867513459481281*y[5]*y[33] + 0.33333333333333326*y[5]*y[41] - 0.28867513459481281*y[4]*y[40] - 0.16666666666666652*y[4]*y[33] + 0.33333333333333326*y[4]*y[34] + 1.0*y[39]*(-0.16666666666666677*y[3] - 0.28867513459481275*y[2]) + 1.0*y[39]*(-0.16666666666666657*y[5] + 0.28867513459481287*y[4]) + 1.0*y[32]*(0.28867513459481275*y[3] - 0.16666666666666677*y[2]) + 1.0*y[32]*(-0.28867513459481287*y[5] - 0.16666666666666657*y[4]);
out[18] = 0.33333333333333331*y[1]*y[39] + 0.33333333333333331*y[1]*y[40] + 0.33333333333333331*y[1]*y[41] + 0.33333333333333331*y[0]*y[32] + 0.33333333333333331*y[0]*y[33] + 0.33333333333333331*y[0]*y[34] + 0.33333333333333331*y[3]*y[39] + 0.33333333333333331*y[3]*y[40] + 0.33333333333333331*y[3]*y[41] + 0.33333333333333331*y[2]*y[32] + 0.33333333333333331*y[2]*y[33] + 0.33333333333333331*y[2]*y[34] + 0.33333333333333331*y[5]*y[39] + 0.33333333333333331*y[5]*y[40] + 0.33333333333333331*y[5]*y[41] + 0.33333333333333331*y[4]*y[32] + 0.33333333333333331*y[4]*y[33] + 0.33333333333333331*y[4]*y[34];
out[19] = u[13];
out[20] = u[14];
out[21] = u[15];
out[22] = u[16];
out[23] = u[17];
out[24] = x[0];
out[25] = u[22];

}
void de_jac_ini_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[1184] = 2.0*y[8]*u[2] - 2.0*y[14]*u[2] + y[24];
out[1185] = 2.0*y[9]*u[2] - 2.0*y[15]*u[2] + y[25];
out[1190] = -2.0*y[8]*u[2] + 2.0*y[14]*u[2] - y[24];
out[1191] = -2.0*y[9]*u[2] + 2.0*y[15]*u[2] - y[25];
out[1200] = y[8] - y[14];
out[1201] = y[9] - y[15];
out[1233] = 2.0*y[10]*u[6] - 2.0*y[14]*u[6] + y[26];
out[1234] = 2.0*y[11]*u[6] - 2.0*y[15]*u[6] + y[27];
out[1237] = -2.0*y[10]*u[6] + 2.0*y[14]*u[6] - y[26];
out[1238] = -2.0*y[11]*u[6] + 2.0*y[15]*u[6] - y[27];
out[1249] = y[10] - y[14];
out[1250] = y[11] - y[15];
out[1282] = 2.0*y[12]*u[10] - 2.0*y[14]*u[10] + y[28];
out[1283] = 2.0*y[13]*u[10] - 2.0*y[15]*u[10] + y[29];
out[1284] = -2.0*y[12]*u[10] + 2.0*y[14]*u[10] - y[28];
out[1285] = -2.0*y[13]*u[10] + 2.0*y[15]*u[10] - y[29];
out[1298] = y[12] - y[14];
out[1299] = y[13] - y[15];
out[1325] = -2.0*y[8]*u[3] + 2.0*y[14]*u[3] - y[25];
out[1326] = -2.0*y[9]*u[3] + 2.0*y[15]*u[3] + y[24];
out[1331] = 2.0*y[8]*u[3] - 2.0*y[14]*u[3] + y[25];
out[1332] = 2.0*y[9]*u[3] - 2.0*y[15]*u[3] - y[24];
out[1341] = y[9] - y[15];
out[1342] = -y[8] + y[14];
out[1374] = -2.0*y[10]*u[7] + 2.0*y[14]*u[7] - y[27];
out[1375] = -2.0*y[11]*u[7] + 2.0*y[15]*u[7] + y[26];
out[1378] = 2.0*y[10]*u[7] - 2.0*y[14]*u[7] + y[27];
out[1379] = 2.0*y[11]*u[7] - 2.0*y[15]*u[7] - y[26];
out[1390] = y[11] - y[15];
out[1391] = -y[10] + y[14];
out[1423] = -2.0*y[12]*u[11] + 2.0*y[14]*u[11] - y[29];
out[1424] = -2.0*y[13]*u[11] + 2.0*y[15]*u[11] + y[28];
out[1425] = 2.0*y[12]*u[11] - 2.0*y[14]*u[11] + y[29];
out[1426] = 2.0*y[13]*u[11] - 2.0*y[15]*u[11] - y[28];
out[1439] = y[13] - y[15];
out[1440] = -y[12] + y[14];
out[2022] = y[32];
out[2023] = 1.0*y[39];
out[2024] = y[33];
out[2025] = 1.0*y[40];
out[2026] = y[34];
out[2027] = 1.0*y[41];
out[2028] = y[34];
out[2029] = 1.0*y[41];
out[2054] = p[48]*y[32]*pow(pow(y[39], 2) + pow(y[32], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[32] + y[0];
out[2055] = p[48]*y[33]*pow(pow(y[40], 2) + pow(y[33], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[33] + y[2];
out[2056] = p[48]*y[34]*pow(pow(y[41], 2) + pow(y[34], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[34] + y[4] + y[6];
out[2057] = p[48]*y[35]*pow(pow(y[42], 2) + pow(y[35], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[35];
out[2061] = p[48]*y[39]*pow(pow(y[39], 2) + pow(y[32], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[39] + 1.0*y[1];
out[2062] = p[48]*y[40]*pow(pow(y[40], 2) + pow(y[33], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[40] + 1.0*y[3];
out[2063] = p[48]*y[41]*pow(pow(y[41], 2) + pow(y[34], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[41] + 1.0*y[5] + 1.0*y[7];
out[2064] = p[48]*y[42]*pow(pow(y[42], 2) + pow(y[35], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[42];

}

void de_jac_ini_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[52];
out[48] = p[0] + p[32];
out[49] = -p[1] - p[33];
out[50] = p[2] + p[34];
out[51] = -p[3] - p[35];
out[52] = p[4];
out[53] = -p[5];
out[54] = p[6];
out[55] = -p[7];
out[56] = -p[0];
out[57] = p[1];
out[58] = -p[2];
out[59] = p[3];
out[60] = -p[4];
out[61] = p[5];
out[62] = -p[6];
out[63] = p[7];
out[64] = -p[32];
out[65] = p[33];
out[66] = -p[34];
out[67] = p[35];
out[95] = p[1] + p[33];
out[96] = p[0] + p[32];
out[97] = p[3] + p[35];
out[98] = p[2] + p[34];
out[99] = p[5];
out[100] = p[4];
out[101] = p[7];
out[102] = p[6];
out[103] = -p[1];
out[104] = -p[0];
out[105] = -p[3];
out[106] = -p[2];
out[107] = -p[5];
out[108] = -p[4];
out[109] = -p[7];
out[110] = -p[6];
out[111] = -p[33];
out[112] = -p[32];
out[113] = -p[35];
out[114] = -p[34];
out[142] = p[8] + p[36];
out[143] = -p[9] - p[37];
out[144] = p[10] + p[38];
out[145] = -p[11] - p[39];
out[146] = p[12];
out[147] = -p[13];
out[148] = p[14];
out[149] = -p[15];
out[150] = -p[8];
out[151] = p[9];
out[152] = -p[10];
out[153] = p[11];
out[154] = -p[12];
out[155] = p[13];
out[156] = -p[14];
out[157] = p[15];
out[158] = -p[36];
out[159] = p[37];
out[160] = -p[38];
out[161] = p[39];
out[189] = p[9] + p[37];
out[190] = p[8] + p[36];
out[191] = p[11] + p[39];
out[192] = p[10] + p[38];
out[193] = p[13];
out[194] = p[12];
out[195] = p[15];
out[196] = p[14];
out[197] = -p[9];
out[198] = -p[8];
out[199] = -p[11];
out[200] = -p[10];
out[201] = -p[13];
out[202] = -p[12];
out[203] = -p[15];
out[204] = -p[14];
out[205] = -p[37];
out[206] = -p[36];
out[207] = -p[39];
out[208] = -p[38];
out[236] = p[16];
out[237] = -p[17];
out[238] = p[18];
out[239] = -p[19];
out[240] = p[20];
out[241] = -p[21];
out[242] = p[22];
out[243] = -p[23];
out[244] = -p[16];
out[245] = p[17];
out[246] = -p[18];
out[247] = p[19];
out[248] = -p[20];
out[249] = p[21];
out[250] = -p[22];
out[251] = p[23];
out[283] = p[17];
out[284] = p[16];
out[285] = p[19];
out[286] = p[18];
out[287] = p[21];
out[288] = p[20];
out[289] = p[23];
out[290] = p[22];
out[291] = -p[17];
out[292] = -p[16];
out[293] = -p[19];
out[294] = -p[18];
out[295] = -p[21];
out[296] = -p[20];
out[297] = -p[23];
out[298] = -p[22];
out[330] = p[24];
out[331] = -p[25];
out[332] = p[26];
out[333] = -p[27];
out[334] = p[28];
out[335] = -p[29];
out[336] = p[30];
out[337] = -p[31];
out[338] = -p[24];
out[339] = p[25];
out[340] = -p[26];
out[341] = p[27];
out[342] = -p[28];
out[343] = p[29];
out[344] = -p[30];
out[345] = p[31];
out[377] = p[25];
out[378] = p[24];
out[379] = p[27];
out[380] = p[26];
out[381] = p[29];
out[382] = p[28];
out[383] = p[31];
out[384] = p[30];
out[385] = -p[25];
out[386] = -p[24];
out[387] = -p[27];
out[388] = -p[26];
out[389] = -p[29];
out[390] = -p[28];
out[391] = -p[31];
out[392] = -p[30];
out[424] = -p[0];
out[425] = p[1];
out[426] = -p[2];
out[427] = p[3];
out[428] = -p[4];
out[429] = p[5];
out[430] = -p[6];
out[431] = p[7];
out[432] = p[0];
out[433] = -p[1];
out[434] = p[2];
out[435] = -p[3];
out[436] = p[4];
out[437] = -p[5];
out[438] = p[6];
out[439] = -p[7];
out[471] = -p[1];
out[472] = -p[0];
out[473] = -p[3];
out[474] = -p[2];
out[475] = -p[5];
out[476] = -p[4];
out[477] = -p[7];
out[478] = -p[6];
out[479] = p[1];
out[480] = p[0];
out[481] = p[3];
out[482] = p[2];
out[483] = p[5];
out[484] = p[4];
out[485] = p[7];
out[486] = p[6];
out[518] = -p[8];
out[519] = p[9];
out[520] = -p[10];
out[521] = p[11];
out[522] = -p[12];
out[523] = p[13];
out[524] = -p[14];
out[525] = p[15];
out[526] = p[8];
out[527] = -p[9];
out[528] = p[10];
out[529] = -p[11];
out[530] = p[12];
out[531] = -p[13];
out[532] = p[14];
out[533] = -p[15];
out[565] = -p[9];
out[566] = -p[8];
out[567] = -p[11];
out[568] = -p[10];
out[569] = -p[13];
out[570] = -p[12];
out[571] = -p[15];
out[572] = -p[14];
out[573] = p[9];
out[574] = p[8];
out[575] = p[11];
out[576] = p[10];
out[577] = p[13];
out[578] = p[12];
out[579] = p[15];
out[580] = p[14];
out[612] = -p[16];
out[613] = p[17];
out[614] = -p[18];
out[615] = p[19];
out[616] = -p[20];
out[617] = p[21];
out[618] = -p[22];
out[619] = p[23];
out[620] = p[16];
out[621] = -p[17];
out[622] = p[18];
out[623] = -p[19];
out[624] = p[20];
out[625] = -p[21];
out[626] = p[22];
out[627] = -p[23];
out[659] = -p[17];
out[660] = -p[16];
out[661] = -p[19];
out[662] = -p[18];
out[663] = -p[21];
out[664] = -p[20];
out[665] = -p[23];
out[666] = -p[22];
out[667] = p[17];
out[668] = p[16];
out[669] = p[19];
out[670] = p[18];
out[671] = p[21];
out[672] = p[20];
out[673] = p[23];
out[674] = p[22];
out[706] = -p[24];
out[707] = p[25];
out[708] = -p[26];
out[709] = p[27];
out[710] = -p[28];
out[711] = p[29];
out[712] = -p[30];
out[713] = p[31];
out[714] = p[24];
out[715] = -p[25];
out[716] = p[26];
out[717] = -p[27];
out[718] = p[28];
out[719] = -p[29];
out[720] = p[30];
out[721] = -p[31];
out[753] = -p[25];
out[754] = -p[24];
out[755] = -p[27];
out[756] = -p[26];
out[757] = -p[29];
out[758] = -p[28];
out[759] = -p[31];
out[760] = -p[30];
out[761] = p[25];
out[762] = p[24];
out[763] = p[27];
out[764] = p[26];
out[765] = p[29];
out[766] = p[28];
out[767] = p[31];
out[768] = p[30];
out[800] = -p[32];
out[801] = p[33];
out[802] = -p[34];
out[803] = p[35];
out[816] = p[32];
out[817] = -p[33];
out[818] = p[34];
out[819] = -p[35];
out[847] = -p[33];
out[848] = -p[32];
out[849] = -p[35];
out[850] = -p[34];
out[863] = p[33];
out[864] = p[32];
out[865] = p[35];
out[866] = p[34];
out[894] = -p[36];
out[895] = p[37];
out[896] = -p[38];
out[897] = p[39];
out[910] = p[36];
out[911] = -p[37];
out[912] = p[38];
out[913] = -p[39];
out[941] = -p[37];
out[942] = -p[36];
out[943] = -p[39];
out[944] = -p[38];
out[957] = p[37];
out[958] = p[36];
out[959] = p[39];
out[960] = p[38];
out[1584] = -p[41];
out[1591] = 1.0*p[40];
out[1632] = -p[41];
out[1639] = 1.0*p[40];
out[1680] = -p[41];
out[1687] = 1.0*p[40];
out[1728] = -p[43];
out[1735] = 1.0*p[42];
out[1776] = p[45]/(pow(p[45], 2) + 1.0*pow(p[44], 2));
out[1783] = 1.0*p[44]/(pow(p[45], 2) + 1.0*pow(p[44], 2));
out[1819] = -1.0*p[40];
out[1826] = -1.0*p[41];
out[1867] = -1.0*p[40];
out[1874] = -1.0*p[41];
out[1915] = -1.0*p[40];
out[1922] = -1.0*p[41];
out[1963] = -1.0*p[42];
out[1970] = -1.0*p[43];
out[2011] = -1.0*p[44]/(pow(p[45], 2) + 1.0*pow(p[44], 2));
out[2018] = 1.0*p[45]/(pow(p[45], 2) + 1.0*pow(p[44], 2));
out[2106] = 1.0/u[12];
out[2162] = p[51];
out[2207] = -p[50];

}

void de_jac_ini_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[45] = -1.0;
out[80] = -1.0;
out[134] = -1.0;
out[175] = -1.0;
out[229] = -1.0;
out[270] = -1.0;
out[324] = -1.0;
out[365] = -1.0;
out[419] = -1.0;
out[448] = -1.0;
out[496] = -1.0;
out[544] = -1.0;
out[592] = -1.0;
out[640] = -1.0;
out[688] = -1.0;
out[736] = -1.0;
out[784] = -1.0;
out[1482] = 1.0;
out[1484] = 1.0;
out[1486] = 1.0;
out[1488] = 1.0;
out[1530] = 1.0;
out[1532] = 1.0;
out[1534] = 1.0;
out[1536] = 1.0;
out[1552] = -1.0;
out[1588] = 1.0;
out[1601] = -1.0;
out[1635] = 1.0;
out[1650] = -1.0;
out[1682] = 1.0;
out[1699] = -1.0;
out[1729] = 1.0;
out[1772] = 1.0;
out[1773] = 1.0;
out[1774] = 1.0;
out[1775] = 1.0;
out[1788] = -1.0;
out[1830] = 1.0;
out[1837] = -1.0;
out[1877] = 1.0;
out[1886] = -1.0;
out[1924] = 1.0;
out[1935] = -1.0;
out[1971] = 1.0;
out[2014] = 1.0;
out[2015] = 1.0;
out[2016] = 1.0;
out[2017] = 1.0;
out[2059] = -1.0;
out[2107] = -1.0;
out[2160] = -1.0;
out[2208] = -1.0;

}

void sp_jac_ini_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[322] = 2.0*y[8]*u[2] - 2.0*y[14]*u[2] + y[24];
out[323] = 2.0*y[9]*u[2] - 2.0*y[15]*u[2] + y[25];
out[324] = -2.0*y[8]*u[2] + 2.0*y[14]*u[2] - y[24];
out[325] = -2.0*y[9]*u[2] + 2.0*y[15]*u[2] - y[25];
out[326] = y[8] - y[14];
out[327] = y[9] - y[15];
out[328] = 2.0*y[10]*u[6] - 2.0*y[14]*u[6] + y[26];
out[329] = 2.0*y[11]*u[6] - 2.0*y[15]*u[6] + y[27];
out[330] = -2.0*y[10]*u[6] + 2.0*y[14]*u[6] - y[26];
out[331] = -2.0*y[11]*u[6] + 2.0*y[15]*u[6] - y[27];
out[332] = y[10] - y[14];
out[333] = y[11] - y[15];
out[334] = 2.0*y[12]*u[10] - 2.0*y[14]*u[10] + y[28];
out[335] = 2.0*y[13]*u[10] - 2.0*y[15]*u[10] + y[29];
out[336] = -2.0*y[12]*u[10] + 2.0*y[14]*u[10] - y[28];
out[337] = -2.0*y[13]*u[10] + 2.0*y[15]*u[10] - y[29];
out[338] = y[12] - y[14];
out[339] = y[13] - y[15];
out[340] = -2.0*y[8]*u[3] + 2.0*y[14]*u[3] - y[25];
out[341] = -2.0*y[9]*u[3] + 2.0*y[15]*u[3] + y[24];
out[342] = 2.0*y[8]*u[3] - 2.0*y[14]*u[3] + y[25];
out[343] = 2.0*y[9]*u[3] - 2.0*y[15]*u[3] - y[24];
out[344] = y[9] - y[15];
out[345] = -y[8] + y[14];
out[346] = -2.0*y[10]*u[7] + 2.0*y[14]*u[7] - y[27];
out[347] = -2.0*y[11]*u[7] + 2.0*y[15]*u[7] + y[26];
out[348] = 2.0*y[10]*u[7] - 2.0*y[14]*u[7] + y[27];
out[349] = 2.0*y[11]*u[7] - 2.0*y[15]*u[7] - y[26];
out[350] = y[11] - y[15];
out[351] = -y[10] + y[14];
out[352] = -2.0*y[12]*u[11] + 2.0*y[14]*u[11] - y[29];
out[353] = -2.0*y[13]*u[11] + 2.0*y[15]*u[11] + y[28];
out[354] = 2.0*y[12]*u[11] - 2.0*y[14]*u[11] + y[29];
out[355] = 2.0*y[13]*u[11] - 2.0*y[15]*u[11] - y[28];
out[356] = y[13] - y[15];
out[357] = -y[12] + y[14];
out[410] = y[32];
out[411] = 1.0*y[39];
out[412] = y[33];
out[413] = 1.0*y[40];
out[414] = y[34];
out[415] = 1.0*y[41];
out[416] = y[34];
out[417] = 1.0*y[41];
out[418] = p[48]*y[32]*pow(pow(y[39], 2) + pow(y[32], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[32] + y[0];
out[419] = p[48]*y[33]*pow(pow(y[40], 2) + pow(y[33], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[33] + y[2];
out[420] = p[48]*y[34]*pow(pow(y[41], 2) + pow(y[34], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[34] + y[4] + y[6];
out[421] = p[48]*y[35]*pow(pow(y[42], 2) + pow(y[35], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[35];
out[423] = p[48]*y[39]*pow(pow(y[39], 2) + pow(y[32], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[39] + 1.0*y[1];
out[424] = p[48]*y[40]*pow(pow(y[40], 2) + pow(y[33], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[40] + 1.0*y[3];
out[425] = p[48]*y[41]*pow(pow(y[41], 2) + pow(y[34], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[41] + 1.0*y[5] + 1.0*y[7];
out[426] = p[48]*y[42]*pow(pow(y[42], 2) + pow(y[35], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[42];

}

void sp_jac_ini_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[52];
out[2] = p[0] + p[32];
out[3] = -p[1] - p[33];
out[4] = p[2] + p[34];
out[5] = -p[3] - p[35];
out[6] = p[4];
out[7] = -p[5];
out[8] = p[6];
out[9] = -p[7];
out[10] = -p[0];
out[11] = p[1];
out[12] = -p[2];
out[13] = p[3];
out[14] = -p[4];
out[15] = p[5];
out[16] = -p[6];
out[17] = p[7];
out[18] = -p[32];
out[19] = p[33];
out[20] = -p[34];
out[21] = p[35];
out[23] = p[1] + p[33];
out[24] = p[0] + p[32];
out[25] = p[3] + p[35];
out[26] = p[2] + p[34];
out[27] = p[5];
out[28] = p[4];
out[29] = p[7];
out[30] = p[6];
out[31] = -p[1];
out[32] = -p[0];
out[33] = -p[3];
out[34] = -p[2];
out[35] = -p[5];
out[36] = -p[4];
out[37] = -p[7];
out[38] = -p[6];
out[39] = -p[33];
out[40] = -p[32];
out[41] = -p[35];
out[42] = -p[34];
out[44] = p[8] + p[36];
out[45] = -p[9] - p[37];
out[46] = p[10] + p[38];
out[47] = -p[11] - p[39];
out[48] = p[12];
out[49] = -p[13];
out[50] = p[14];
out[51] = -p[15];
out[52] = -p[8];
out[53] = p[9];
out[54] = -p[10];
out[55] = p[11];
out[56] = -p[12];
out[57] = p[13];
out[58] = -p[14];
out[59] = p[15];
out[60] = -p[36];
out[61] = p[37];
out[62] = -p[38];
out[63] = p[39];
out[65] = p[9] + p[37];
out[66] = p[8] + p[36];
out[67] = p[11] + p[39];
out[68] = p[10] + p[38];
out[69] = p[13];
out[70] = p[12];
out[71] = p[15];
out[72] = p[14];
out[73] = -p[9];
out[74] = -p[8];
out[75] = -p[11];
out[76] = -p[10];
out[77] = -p[13];
out[78] = -p[12];
out[79] = -p[15];
out[80] = -p[14];
out[81] = -p[37];
out[82] = -p[36];
out[83] = -p[39];
out[84] = -p[38];
out[86] = p[16];
out[87] = -p[17];
out[88] = p[18];
out[89] = -p[19];
out[90] = p[20];
out[91] = -p[21];
out[92] = p[22];
out[93] = -p[23];
out[94] = -p[16];
out[95] = p[17];
out[96] = -p[18];
out[97] = p[19];
out[98] = -p[20];
out[99] = p[21];
out[100] = -p[22];
out[101] = p[23];
out[103] = p[17];
out[104] = p[16];
out[105] = p[19];
out[106] = p[18];
out[107] = p[21];
out[108] = p[20];
out[109] = p[23];
out[110] = p[22];
out[111] = -p[17];
out[112] = -p[16];
out[113] = -p[19];
out[114] = -p[18];
out[115] = -p[21];
out[116] = -p[20];
out[117] = -p[23];
out[118] = -p[22];
out[120] = p[24];
out[121] = -p[25];
out[122] = p[26];
out[123] = -p[27];
out[124] = p[28];
out[125] = -p[29];
out[126] = p[30];
out[127] = -p[31];
out[128] = -p[24];
out[129] = p[25];
out[130] = -p[26];
out[131] = p[27];
out[132] = -p[28];
out[133] = p[29];
out[134] = -p[30];
out[135] = p[31];
out[137] = p[25];
out[138] = p[24];
out[139] = p[27];
out[140] = p[26];
out[141] = p[29];
out[142] = p[28];
out[143] = p[31];
out[144] = p[30];
out[145] = -p[25];
out[146] = -p[24];
out[147] = -p[27];
out[148] = -p[26];
out[149] = -p[29];
out[150] = -p[28];
out[151] = -p[31];
out[152] = -p[30];
out[154] = -p[0];
out[155] = p[1];
out[156] = -p[2];
out[157] = p[3];
out[158] = -p[4];
out[159] = p[5];
out[160] = -p[6];
out[161] = p[7];
out[162] = p[0];
out[163] = -p[1];
out[164] = p[2];
out[165] = -p[3];
out[166] = p[4];
out[167] = -p[5];
out[168] = p[6];
out[169] = -p[7];
out[171] = -p[1];
out[172] = -p[0];
out[173] = -p[3];
out[174] = -p[2];
out[175] = -p[5];
out[176] = -p[4];
out[177] = -p[7];
out[178] = -p[6];
out[179] = p[1];
out[180] = p[0];
out[181] = p[3];
out[182] = p[2];
out[183] = p[5];
out[184] = p[4];
out[185] = p[7];
out[186] = p[6];
out[188] = -p[8];
out[189] = p[9];
out[190] = -p[10];
out[191] = p[11];
out[192] = -p[12];
out[193] = p[13];
out[194] = -p[14];
out[195] = p[15];
out[196] = p[8];
out[197] = -p[9];
out[198] = p[10];
out[199] = -p[11];
out[200] = p[12];
out[201] = -p[13];
out[202] = p[14];
out[203] = -p[15];
out[205] = -p[9];
out[206] = -p[8];
out[207] = -p[11];
out[208] = -p[10];
out[209] = -p[13];
out[210] = -p[12];
out[211] = -p[15];
out[212] = -p[14];
out[213] = p[9];
out[214] = p[8];
out[215] = p[11];
out[216] = p[10];
out[217] = p[13];
out[218] = p[12];
out[219] = p[15];
out[220] = p[14];
out[222] = -p[16];
out[223] = p[17];
out[224] = -p[18];
out[225] = p[19];
out[226] = -p[20];
out[227] = p[21];
out[228] = -p[22];
out[229] = p[23];
out[230] = p[16];
out[231] = -p[17];
out[232] = p[18];
out[233] = -p[19];
out[234] = p[20];
out[235] = -p[21];
out[236] = p[22];
out[237] = -p[23];
out[239] = -p[17];
out[240] = -p[16];
out[241] = -p[19];
out[242] = -p[18];
out[243] = -p[21];
out[244] = -p[20];
out[245] = -p[23];
out[246] = -p[22];
out[247] = p[17];
out[248] = p[16];
out[249] = p[19];
out[250] = p[18];
out[251] = p[21];
out[252] = p[20];
out[253] = p[23];
out[254] = p[22];
out[256] = -p[24];
out[257] = p[25];
out[258] = -p[26];
out[259] = p[27];
out[260] = -p[28];
out[261] = p[29];
out[262] = -p[30];
out[263] = p[31];
out[264] = p[24];
out[265] = -p[25];
out[266] = p[26];
out[267] = -p[27];
out[268] = p[28];
out[269] = -p[29];
out[270] = p[30];
out[271] = -p[31];
out[273] = -p[25];
out[274] = -p[24];
out[275] = -p[27];
out[276] = -p[26];
out[277] = -p[29];
out[278] = -p[28];
out[279] = -p[31];
out[280] = -p[30];
out[281] = p[25];
out[282] = p[24];
out[283] = p[27];
out[284] = p[26];
out[285] = p[29];
out[286] = p[28];
out[287] = p[31];
out[288] = p[30];
out[290] = -p[32];
out[291] = p[33];
out[292] = -p[34];
out[293] = p[35];
out[294] = p[32];
out[295] = -p[33];
out[296] = p[34];
out[297] = -p[35];
out[298] = -p[33];
out[299] = -p[32];
out[300] = -p[35];
out[301] = -p[34];
out[302] = p[33];
out[303] = p[32];
out[304] = p[35];
out[305] = p[34];
out[306] = -p[36];
out[307] = p[37];
out[308] = -p[38];
out[309] = p[39];
out[310] = p[36];
out[311] = -p[37];
out[312] = p[38];
out[313] = -p[39];
out[314] = -p[37];
out[315] = -p[36];
out[316] = -p[39];
out[317] = -p[38];
out[318] = p[37];
out[319] = p[36];
out[320] = p[39];
out[321] = p[38];
out[367] = -p[41];
out[369] = 1.0*p[40];
out[371] = -p[41];
out[373] = 1.0*p[40];
out[375] = -p[41];
out[377] = 1.0*p[40];
out[379] = -p[43];
out[381] = 1.0*p[42];
out[386] = p[45]/(pow(p[45], 2) + 1.0*pow(p[44], 2));
out[387] = 1.0*p[44]/(pow(p[45], 2) + 1.0*pow(p[44], 2));
out[389] = -1.0*p[40];
out[390] = -1.0*p[41];
out[393] = -1.0*p[40];
out[394] = -1.0*p[41];
out[397] = -1.0*p[40];
out[398] = -1.0*p[41];
out[401] = -1.0*p[42];
out[402] = -1.0*p[43];
out[404] = -1.0*p[44]/(pow(p[45], 2) + 1.0*pow(p[44], 2));
out[409] = 1.0*p[45]/(pow(p[45], 2) + 1.0*pow(p[44], 2));
out[427] = 1.0/u[12];
out[430] = p[51];
out[431] = -p[50];

}

void sp_jac_ini_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[1] = -1.0;
out[22] = -1.0;
out[43] = -1.0;
out[64] = -1.0;
out[85] = -1.0;
out[102] = -1.0;
out[119] = -1.0;
out[136] = -1.0;
out[153] = -1.0;
out[170] = -1.0;
out[187] = -1.0;
out[204] = -1.0;
out[221] = -1.0;
out[238] = -1.0;
out[255] = -1.0;
out[272] = -1.0;
out[289] = -1.0;
out[358] = 1.0;
out[359] = 1.0;
out[360] = 1.0;
out[361] = 1.0;
out[362] = 1.0;
out[363] = 1.0;
out[364] = 1.0;
out[365] = 1.0;
out[366] = -1.0;
out[368] = 1.0;
out[370] = -1.0;
out[372] = 1.0;
out[374] = -1.0;
out[376] = 1.0;
out[378] = -1.0;
out[380] = 1.0;
out[382] = 1.0;
out[383] = 1.0;
out[384] = 1.0;
out[385] = 1.0;
out[388] = -1.0;
out[391] = 1.0;
out[392] = -1.0;
out[395] = 1.0;
out[396] = -1.0;
out[399] = 1.0;
out[400] = -1.0;
out[403] = 1.0;
out[405] = 1.0;
out[406] = 1.0;
out[407] = 1.0;
out[408] = 1.0;
out[422] = -1.0;
out[428] = -1.0;
out[429] = -1.0;
out[432] = -1.0;

}

void de_jac_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[1184] = 2.0*y[8]*u[2] - 2.0*y[14]*u[2] + y[24];
out[1185] = 2.0*y[9]*u[2] - 2.0*y[15]*u[2] + y[25];
out[1190] = -2.0*y[8]*u[2] + 2.0*y[14]*u[2] - y[24];
out[1191] = -2.0*y[9]*u[2] + 2.0*y[15]*u[2] - y[25];
out[1200] = y[8] - y[14];
out[1201] = y[9] - y[15];
out[1233] = 2.0*y[10]*u[6] - 2.0*y[14]*u[6] + y[26];
out[1234] = 2.0*y[11]*u[6] - 2.0*y[15]*u[6] + y[27];
out[1237] = -2.0*y[10]*u[6] + 2.0*y[14]*u[6] - y[26];
out[1238] = -2.0*y[11]*u[6] + 2.0*y[15]*u[6] - y[27];
out[1249] = y[10] - y[14];
out[1250] = y[11] - y[15];
out[1282] = 2.0*y[12]*u[10] - 2.0*y[14]*u[10] + y[28];
out[1283] = 2.0*y[13]*u[10] - 2.0*y[15]*u[10] + y[29];
out[1284] = -2.0*y[12]*u[10] + 2.0*y[14]*u[10] - y[28];
out[1285] = -2.0*y[13]*u[10] + 2.0*y[15]*u[10] - y[29];
out[1298] = y[12] - y[14];
out[1299] = y[13] - y[15];
out[1325] = -2.0*y[8]*u[3] + 2.0*y[14]*u[3] - y[25];
out[1326] = -2.0*y[9]*u[3] + 2.0*y[15]*u[3] + y[24];
out[1331] = 2.0*y[8]*u[3] - 2.0*y[14]*u[3] + y[25];
out[1332] = 2.0*y[9]*u[3] - 2.0*y[15]*u[3] - y[24];
out[1341] = y[9] - y[15];
out[1342] = -y[8] + y[14];
out[1374] = -2.0*y[10]*u[7] + 2.0*y[14]*u[7] - y[27];
out[1375] = -2.0*y[11]*u[7] + 2.0*y[15]*u[7] + y[26];
out[1378] = 2.0*y[10]*u[7] - 2.0*y[14]*u[7] + y[27];
out[1379] = 2.0*y[11]*u[7] - 2.0*y[15]*u[7] - y[26];
out[1390] = y[11] - y[15];
out[1391] = -y[10] + y[14];
out[1423] = -2.0*y[12]*u[11] + 2.0*y[14]*u[11] - y[29];
out[1424] = -2.0*y[13]*u[11] + 2.0*y[15]*u[11] + y[28];
out[1425] = 2.0*y[12]*u[11] - 2.0*y[14]*u[11] + y[29];
out[1426] = 2.0*y[13]*u[11] - 2.0*y[15]*u[11] - y[28];
out[1439] = y[13] - y[15];
out[1440] = -y[12] + y[14];
out[2022] = y[32];
out[2023] = 1.0*y[39];
out[2024] = y[33];
out[2025] = 1.0*y[40];
out[2026] = y[34];
out[2027] = 1.0*y[41];
out[2028] = y[34];
out[2029] = 1.0*y[41];
out[2054] = p[48]*y[32]*pow(pow(y[39], 2) + pow(y[32], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[32] + y[0];
out[2055] = p[48]*y[33]*pow(pow(y[40], 2) + pow(y[33], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[33] + y[2];
out[2056] = p[48]*y[34]*pow(pow(y[41], 2) + pow(y[34], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[34] + y[4] + y[6];
out[2057] = p[48]*y[35]*pow(pow(y[42], 2) + pow(y[35], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[35];
out[2061] = p[48]*y[39]*pow(pow(y[39], 2) + pow(y[32], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[39] + 1.0*y[1];
out[2062] = p[48]*y[40]*pow(pow(y[40], 2) + pow(y[33], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[40] + 1.0*y[3];
out[2063] = p[48]*y[41]*pow(pow(y[41], 2) + pow(y[34], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[41] + 1.0*y[5] + 1.0*y[7];
out[2064] = p[48]*y[42]*pow(pow(y[42], 2) + pow(y[35], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[42];

}

void de_jac_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[52];
out[48] = p[0] + p[32];
out[49] = -p[1] - p[33];
out[50] = p[2] + p[34];
out[51] = -p[3] - p[35];
out[52] = p[4];
out[53] = -p[5];
out[54] = p[6];
out[55] = -p[7];
out[56] = -p[0];
out[57] = p[1];
out[58] = -p[2];
out[59] = p[3];
out[60] = -p[4];
out[61] = p[5];
out[62] = -p[6];
out[63] = p[7];
out[64] = -p[32];
out[65] = p[33];
out[66] = -p[34];
out[67] = p[35];
out[95] = p[1] + p[33];
out[96] = p[0] + p[32];
out[97] = p[3] + p[35];
out[98] = p[2] + p[34];
out[99] = p[5];
out[100] = p[4];
out[101] = p[7];
out[102] = p[6];
out[103] = -p[1];
out[104] = -p[0];
out[105] = -p[3];
out[106] = -p[2];
out[107] = -p[5];
out[108] = -p[4];
out[109] = -p[7];
out[110] = -p[6];
out[111] = -p[33];
out[112] = -p[32];
out[113] = -p[35];
out[114] = -p[34];
out[142] = p[8] + p[36];
out[143] = -p[9] - p[37];
out[144] = p[10] + p[38];
out[145] = -p[11] - p[39];
out[146] = p[12];
out[147] = -p[13];
out[148] = p[14];
out[149] = -p[15];
out[150] = -p[8];
out[151] = p[9];
out[152] = -p[10];
out[153] = p[11];
out[154] = -p[12];
out[155] = p[13];
out[156] = -p[14];
out[157] = p[15];
out[158] = -p[36];
out[159] = p[37];
out[160] = -p[38];
out[161] = p[39];
out[189] = p[9] + p[37];
out[190] = p[8] + p[36];
out[191] = p[11] + p[39];
out[192] = p[10] + p[38];
out[193] = p[13];
out[194] = p[12];
out[195] = p[15];
out[196] = p[14];
out[197] = -p[9];
out[198] = -p[8];
out[199] = -p[11];
out[200] = -p[10];
out[201] = -p[13];
out[202] = -p[12];
out[203] = -p[15];
out[204] = -p[14];
out[205] = -p[37];
out[206] = -p[36];
out[207] = -p[39];
out[208] = -p[38];
out[236] = p[16];
out[237] = -p[17];
out[238] = p[18];
out[239] = -p[19];
out[240] = p[20];
out[241] = -p[21];
out[242] = p[22];
out[243] = -p[23];
out[244] = -p[16];
out[245] = p[17];
out[246] = -p[18];
out[247] = p[19];
out[248] = -p[20];
out[249] = p[21];
out[250] = -p[22];
out[251] = p[23];
out[283] = p[17];
out[284] = p[16];
out[285] = p[19];
out[286] = p[18];
out[287] = p[21];
out[288] = p[20];
out[289] = p[23];
out[290] = p[22];
out[291] = -p[17];
out[292] = -p[16];
out[293] = -p[19];
out[294] = -p[18];
out[295] = -p[21];
out[296] = -p[20];
out[297] = -p[23];
out[298] = -p[22];
out[330] = p[24];
out[331] = -p[25];
out[332] = p[26];
out[333] = -p[27];
out[334] = p[28];
out[335] = -p[29];
out[336] = p[30];
out[337] = -p[31];
out[338] = -p[24];
out[339] = p[25];
out[340] = -p[26];
out[341] = p[27];
out[342] = -p[28];
out[343] = p[29];
out[344] = -p[30];
out[345] = p[31];
out[377] = p[25];
out[378] = p[24];
out[379] = p[27];
out[380] = p[26];
out[381] = p[29];
out[382] = p[28];
out[383] = p[31];
out[384] = p[30];
out[385] = -p[25];
out[386] = -p[24];
out[387] = -p[27];
out[388] = -p[26];
out[389] = -p[29];
out[390] = -p[28];
out[391] = -p[31];
out[392] = -p[30];
out[424] = -p[0];
out[425] = p[1];
out[426] = -p[2];
out[427] = p[3];
out[428] = -p[4];
out[429] = p[5];
out[430] = -p[6];
out[431] = p[7];
out[432] = p[0];
out[433] = -p[1];
out[434] = p[2];
out[435] = -p[3];
out[436] = p[4];
out[437] = -p[5];
out[438] = p[6];
out[439] = -p[7];
out[471] = -p[1];
out[472] = -p[0];
out[473] = -p[3];
out[474] = -p[2];
out[475] = -p[5];
out[476] = -p[4];
out[477] = -p[7];
out[478] = -p[6];
out[479] = p[1];
out[480] = p[0];
out[481] = p[3];
out[482] = p[2];
out[483] = p[5];
out[484] = p[4];
out[485] = p[7];
out[486] = p[6];
out[518] = -p[8];
out[519] = p[9];
out[520] = -p[10];
out[521] = p[11];
out[522] = -p[12];
out[523] = p[13];
out[524] = -p[14];
out[525] = p[15];
out[526] = p[8];
out[527] = -p[9];
out[528] = p[10];
out[529] = -p[11];
out[530] = p[12];
out[531] = -p[13];
out[532] = p[14];
out[533] = -p[15];
out[565] = -p[9];
out[566] = -p[8];
out[567] = -p[11];
out[568] = -p[10];
out[569] = -p[13];
out[570] = -p[12];
out[571] = -p[15];
out[572] = -p[14];
out[573] = p[9];
out[574] = p[8];
out[575] = p[11];
out[576] = p[10];
out[577] = p[13];
out[578] = p[12];
out[579] = p[15];
out[580] = p[14];
out[612] = -p[16];
out[613] = p[17];
out[614] = -p[18];
out[615] = p[19];
out[616] = -p[20];
out[617] = p[21];
out[618] = -p[22];
out[619] = p[23];
out[620] = p[16];
out[621] = -p[17];
out[622] = p[18];
out[623] = -p[19];
out[624] = p[20];
out[625] = -p[21];
out[626] = p[22];
out[627] = -p[23];
out[659] = -p[17];
out[660] = -p[16];
out[661] = -p[19];
out[662] = -p[18];
out[663] = -p[21];
out[664] = -p[20];
out[665] = -p[23];
out[666] = -p[22];
out[667] = p[17];
out[668] = p[16];
out[669] = p[19];
out[670] = p[18];
out[671] = p[21];
out[672] = p[20];
out[673] = p[23];
out[674] = p[22];
out[706] = -p[24];
out[707] = p[25];
out[708] = -p[26];
out[709] = p[27];
out[710] = -p[28];
out[711] = p[29];
out[712] = -p[30];
out[713] = p[31];
out[714] = p[24];
out[715] = -p[25];
out[716] = p[26];
out[717] = -p[27];
out[718] = p[28];
out[719] = -p[29];
out[720] = p[30];
out[721] = -p[31];
out[753] = -p[25];
out[754] = -p[24];
out[755] = -p[27];
out[756] = -p[26];
out[757] = -p[29];
out[758] = -p[28];
out[759] = -p[31];
out[760] = -p[30];
out[761] = p[25];
out[762] = p[24];
out[763] = p[27];
out[764] = p[26];
out[765] = p[29];
out[766] = p[28];
out[767] = p[31];
out[768] = p[30];
out[800] = -p[32];
out[801] = p[33];
out[802] = -p[34];
out[803] = p[35];
out[816] = p[32];
out[817] = -p[33];
out[818] = p[34];
out[819] = -p[35];
out[847] = -p[33];
out[848] = -p[32];
out[849] = -p[35];
out[850] = -p[34];
out[863] = p[33];
out[864] = p[32];
out[865] = p[35];
out[866] = p[34];
out[894] = -p[36];
out[895] = p[37];
out[896] = -p[38];
out[897] = p[39];
out[910] = p[36];
out[911] = -p[37];
out[912] = p[38];
out[913] = -p[39];
out[941] = -p[37];
out[942] = -p[36];
out[943] = -p[39];
out[944] = -p[38];
out[957] = p[37];
out[958] = p[36];
out[959] = p[39];
out[960] = p[38];
out[1584] = -p[41];
out[1591] = 1.0*p[40];
out[1632] = -p[41];
out[1639] = 1.0*p[40];
out[1680] = -p[41];
out[1687] = 1.0*p[40];
out[1728] = -p[43];
out[1735] = 1.0*p[42];
out[1776] = p[45]/(pow(p[45], 2) + 1.0*pow(p[44], 2));
out[1783] = 1.0*p[44]/(pow(p[45], 2) + 1.0*pow(p[44], 2));
out[1819] = -1.0*p[40];
out[1826] = -1.0*p[41];
out[1867] = -1.0*p[40];
out[1874] = -1.0*p[41];
out[1915] = -1.0*p[40];
out[1922] = -1.0*p[41];
out[1963] = -1.0*p[42];
out[1970] = -1.0*p[43];
out[2011] = -1.0*p[44]/(pow(p[45], 2) + 1.0*pow(p[44], 2));
out[2018] = 1.0*p[45]/(pow(p[45], 2) + 1.0*pow(p[44], 2));
out[2106] = 1.0/u[12];
out[2162] = p[51];
out[2207] = -p[50];

}

void de_jac_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[45] = -1.0;
out[80] = -1.0;
out[134] = -1.0;
out[175] = -1.0;
out[229] = -1.0;
out[270] = -1.0;
out[324] = -1.0;
out[365] = -1.0;
out[419] = -1.0;
out[448] = -1.0;
out[496] = -1.0;
out[544] = -1.0;
out[592] = -1.0;
out[640] = -1.0;
out[688] = -1.0;
out[736] = -1.0;
out[784] = -1.0;
out[1482] = 1.0;
out[1484] = 1.0;
out[1486] = 1.0;
out[1488] = 1.0;
out[1530] = 1.0;
out[1532] = 1.0;
out[1534] = 1.0;
out[1536] = 1.0;
out[1552] = -1.0;
out[1588] = 1.0;
out[1601] = -1.0;
out[1635] = 1.0;
out[1650] = -1.0;
out[1682] = 1.0;
out[1699] = -1.0;
out[1729] = 1.0;
out[1772] = 1.0;
out[1773] = 1.0;
out[1774] = 1.0;
out[1775] = 1.0;
out[1788] = -1.0;
out[1830] = 1.0;
out[1837] = -1.0;
out[1877] = 1.0;
out[1886] = -1.0;
out[1924] = 1.0;
out[1935] = -1.0;
out[1971] = 1.0;
out[2014] = 1.0;
out[2015] = 1.0;
out[2016] = 1.0;
out[2017] = 1.0;
out[2059] = -1.0;
out[2107] = -1.0;
out[2160] = -1.0;
out[2208] = -1.0;

}

void sp_jac_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[322] = 2.0*y[8]*u[2] - 2.0*y[14]*u[2] + y[24];
out[323] = 2.0*y[9]*u[2] - 2.0*y[15]*u[2] + y[25];
out[324] = -2.0*y[8]*u[2] + 2.0*y[14]*u[2] - y[24];
out[325] = -2.0*y[9]*u[2] + 2.0*y[15]*u[2] - y[25];
out[326] = y[8] - y[14];
out[327] = y[9] - y[15];
out[328] = 2.0*y[10]*u[6] - 2.0*y[14]*u[6] + y[26];
out[329] = 2.0*y[11]*u[6] - 2.0*y[15]*u[6] + y[27];
out[330] = -2.0*y[10]*u[6] + 2.0*y[14]*u[6] - y[26];
out[331] = -2.0*y[11]*u[6] + 2.0*y[15]*u[6] - y[27];
out[332] = y[10] - y[14];
out[333] = y[11] - y[15];
out[334] = 2.0*y[12]*u[10] - 2.0*y[14]*u[10] + y[28];
out[335] = 2.0*y[13]*u[10] - 2.0*y[15]*u[10] + y[29];
out[336] = -2.0*y[12]*u[10] + 2.0*y[14]*u[10] - y[28];
out[337] = -2.0*y[13]*u[10] + 2.0*y[15]*u[10] - y[29];
out[338] = y[12] - y[14];
out[339] = y[13] - y[15];
out[340] = -2.0*y[8]*u[3] + 2.0*y[14]*u[3] - y[25];
out[341] = -2.0*y[9]*u[3] + 2.0*y[15]*u[3] + y[24];
out[342] = 2.0*y[8]*u[3] - 2.0*y[14]*u[3] + y[25];
out[343] = 2.0*y[9]*u[3] - 2.0*y[15]*u[3] - y[24];
out[344] = y[9] - y[15];
out[345] = -y[8] + y[14];
out[346] = -2.0*y[10]*u[7] + 2.0*y[14]*u[7] - y[27];
out[347] = -2.0*y[11]*u[7] + 2.0*y[15]*u[7] + y[26];
out[348] = 2.0*y[10]*u[7] - 2.0*y[14]*u[7] + y[27];
out[349] = 2.0*y[11]*u[7] - 2.0*y[15]*u[7] - y[26];
out[350] = y[11] - y[15];
out[351] = -y[10] + y[14];
out[352] = -2.0*y[12]*u[11] + 2.0*y[14]*u[11] - y[29];
out[353] = -2.0*y[13]*u[11] + 2.0*y[15]*u[11] + y[28];
out[354] = 2.0*y[12]*u[11] - 2.0*y[14]*u[11] + y[29];
out[355] = 2.0*y[13]*u[11] - 2.0*y[15]*u[11] - y[28];
out[356] = y[13] - y[15];
out[357] = -y[12] + y[14];
out[410] = y[32];
out[411] = 1.0*y[39];
out[412] = y[33];
out[413] = 1.0*y[40];
out[414] = y[34];
out[415] = 1.0*y[41];
out[416] = y[34];
out[417] = 1.0*y[41];
out[418] = p[48]*y[32]*pow(pow(y[39], 2) + pow(y[32], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[32] + y[0];
out[419] = p[48]*y[33]*pow(pow(y[40], 2) + pow(y[33], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[33] + y[2];
out[420] = p[48]*y[34]*pow(pow(y[41], 2) + pow(y[34], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[34] + y[4] + y[6];
out[421] = p[48]*y[35]*pow(pow(y[42], 2) + pow(y[35], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[35];
out[423] = p[48]*y[39]*pow(pow(y[39], 2) + pow(y[32], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[39] + 1.0*y[1];
out[424] = p[48]*y[40]*pow(pow(y[40], 2) + pow(y[33], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[40] + 1.0*y[3];
out[425] = p[48]*y[41]*pow(pow(y[41], 2) + pow(y[34], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[41] + 1.0*y[5] + 1.0*y[7];
out[426] = p[48]*y[42]*pow(pow(y[42], 2) + pow(y[35], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[42];

}

void sp_jac_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[52];
out[2] = p[0] + p[32];
out[3] = -p[1] - p[33];
out[4] = p[2] + p[34];
out[5] = -p[3] - p[35];
out[6] = p[4];
out[7] = -p[5];
out[8] = p[6];
out[9] = -p[7];
out[10] = -p[0];
out[11] = p[1];
out[12] = -p[2];
out[13] = p[3];
out[14] = -p[4];
out[15] = p[5];
out[16] = -p[6];
out[17] = p[7];
out[18] = -p[32];
out[19] = p[33];
out[20] = -p[34];
out[21] = p[35];
out[23] = p[1] + p[33];
out[24] = p[0] + p[32];
out[25] = p[3] + p[35];
out[26] = p[2] + p[34];
out[27] = p[5];
out[28] = p[4];
out[29] = p[7];
out[30] = p[6];
out[31] = -p[1];
out[32] = -p[0];
out[33] = -p[3];
out[34] = -p[2];
out[35] = -p[5];
out[36] = -p[4];
out[37] = -p[7];
out[38] = -p[6];
out[39] = -p[33];
out[40] = -p[32];
out[41] = -p[35];
out[42] = -p[34];
out[44] = p[8] + p[36];
out[45] = -p[9] - p[37];
out[46] = p[10] + p[38];
out[47] = -p[11] - p[39];
out[48] = p[12];
out[49] = -p[13];
out[50] = p[14];
out[51] = -p[15];
out[52] = -p[8];
out[53] = p[9];
out[54] = -p[10];
out[55] = p[11];
out[56] = -p[12];
out[57] = p[13];
out[58] = -p[14];
out[59] = p[15];
out[60] = -p[36];
out[61] = p[37];
out[62] = -p[38];
out[63] = p[39];
out[65] = p[9] + p[37];
out[66] = p[8] + p[36];
out[67] = p[11] + p[39];
out[68] = p[10] + p[38];
out[69] = p[13];
out[70] = p[12];
out[71] = p[15];
out[72] = p[14];
out[73] = -p[9];
out[74] = -p[8];
out[75] = -p[11];
out[76] = -p[10];
out[77] = -p[13];
out[78] = -p[12];
out[79] = -p[15];
out[80] = -p[14];
out[81] = -p[37];
out[82] = -p[36];
out[83] = -p[39];
out[84] = -p[38];
out[86] = p[16];
out[87] = -p[17];
out[88] = p[18];
out[89] = -p[19];
out[90] = p[20];
out[91] = -p[21];
out[92] = p[22];
out[93] = -p[23];
out[94] = -p[16];
out[95] = p[17];
out[96] = -p[18];
out[97] = p[19];
out[98] = -p[20];
out[99] = p[21];
out[100] = -p[22];
out[101] = p[23];
out[103] = p[17];
out[104] = p[16];
out[105] = p[19];
out[106] = p[18];
out[107] = p[21];
out[108] = p[20];
out[109] = p[23];
out[110] = p[22];
out[111] = -p[17];
out[112] = -p[16];
out[113] = -p[19];
out[114] = -p[18];
out[115] = -p[21];
out[116] = -p[20];
out[117] = -p[23];
out[118] = -p[22];
out[120] = p[24];
out[121] = -p[25];
out[122] = p[26];
out[123] = -p[27];
out[124] = p[28];
out[125] = -p[29];
out[126] = p[30];
out[127] = -p[31];
out[128] = -p[24];
out[129] = p[25];
out[130] = -p[26];
out[131] = p[27];
out[132] = -p[28];
out[133] = p[29];
out[134] = -p[30];
out[135] = p[31];
out[137] = p[25];
out[138] = p[24];
out[139] = p[27];
out[140] = p[26];
out[141] = p[29];
out[142] = p[28];
out[143] = p[31];
out[144] = p[30];
out[145] = -p[25];
out[146] = -p[24];
out[147] = -p[27];
out[148] = -p[26];
out[149] = -p[29];
out[150] = -p[28];
out[151] = -p[31];
out[152] = -p[30];
out[154] = -p[0];
out[155] = p[1];
out[156] = -p[2];
out[157] = p[3];
out[158] = -p[4];
out[159] = p[5];
out[160] = -p[6];
out[161] = p[7];
out[162] = p[0];
out[163] = -p[1];
out[164] = p[2];
out[165] = -p[3];
out[166] = p[4];
out[167] = -p[5];
out[168] = p[6];
out[169] = -p[7];
out[171] = -p[1];
out[172] = -p[0];
out[173] = -p[3];
out[174] = -p[2];
out[175] = -p[5];
out[176] = -p[4];
out[177] = -p[7];
out[178] = -p[6];
out[179] = p[1];
out[180] = p[0];
out[181] = p[3];
out[182] = p[2];
out[183] = p[5];
out[184] = p[4];
out[185] = p[7];
out[186] = p[6];
out[188] = -p[8];
out[189] = p[9];
out[190] = -p[10];
out[191] = p[11];
out[192] = -p[12];
out[193] = p[13];
out[194] = -p[14];
out[195] = p[15];
out[196] = p[8];
out[197] = -p[9];
out[198] = p[10];
out[199] = -p[11];
out[200] = p[12];
out[201] = -p[13];
out[202] = p[14];
out[203] = -p[15];
out[205] = -p[9];
out[206] = -p[8];
out[207] = -p[11];
out[208] = -p[10];
out[209] = -p[13];
out[210] = -p[12];
out[211] = -p[15];
out[212] = -p[14];
out[213] = p[9];
out[214] = p[8];
out[215] = p[11];
out[216] = p[10];
out[217] = p[13];
out[218] = p[12];
out[219] = p[15];
out[220] = p[14];
out[222] = -p[16];
out[223] = p[17];
out[224] = -p[18];
out[225] = p[19];
out[226] = -p[20];
out[227] = p[21];
out[228] = -p[22];
out[229] = p[23];
out[230] = p[16];
out[231] = -p[17];
out[232] = p[18];
out[233] = -p[19];
out[234] = p[20];
out[235] = -p[21];
out[236] = p[22];
out[237] = -p[23];
out[239] = -p[17];
out[240] = -p[16];
out[241] = -p[19];
out[242] = -p[18];
out[243] = -p[21];
out[244] = -p[20];
out[245] = -p[23];
out[246] = -p[22];
out[247] = p[17];
out[248] = p[16];
out[249] = p[19];
out[250] = p[18];
out[251] = p[21];
out[252] = p[20];
out[253] = p[23];
out[254] = p[22];
out[256] = -p[24];
out[257] = p[25];
out[258] = -p[26];
out[259] = p[27];
out[260] = -p[28];
out[261] = p[29];
out[262] = -p[30];
out[263] = p[31];
out[264] = p[24];
out[265] = -p[25];
out[266] = p[26];
out[267] = -p[27];
out[268] = p[28];
out[269] = -p[29];
out[270] = p[30];
out[271] = -p[31];
out[273] = -p[25];
out[274] = -p[24];
out[275] = -p[27];
out[276] = -p[26];
out[277] = -p[29];
out[278] = -p[28];
out[279] = -p[31];
out[280] = -p[30];
out[281] = p[25];
out[282] = p[24];
out[283] = p[27];
out[284] = p[26];
out[285] = p[29];
out[286] = p[28];
out[287] = p[31];
out[288] = p[30];
out[290] = -p[32];
out[291] = p[33];
out[292] = -p[34];
out[293] = p[35];
out[294] = p[32];
out[295] = -p[33];
out[296] = p[34];
out[297] = -p[35];
out[298] = -p[33];
out[299] = -p[32];
out[300] = -p[35];
out[301] = -p[34];
out[302] = p[33];
out[303] = p[32];
out[304] = p[35];
out[305] = p[34];
out[306] = -p[36];
out[307] = p[37];
out[308] = -p[38];
out[309] = p[39];
out[310] = p[36];
out[311] = -p[37];
out[312] = p[38];
out[313] = -p[39];
out[314] = -p[37];
out[315] = -p[36];
out[316] = -p[39];
out[317] = -p[38];
out[318] = p[37];
out[319] = p[36];
out[320] = p[39];
out[321] = p[38];
out[367] = -p[41];
out[369] = 1.0*p[40];
out[371] = -p[41];
out[373] = 1.0*p[40];
out[375] = -p[41];
out[377] = 1.0*p[40];
out[379] = -p[43];
out[381] = 1.0*p[42];
out[386] = p[45]/(pow(p[45], 2) + 1.0*pow(p[44], 2));
out[387] = 1.0*p[44]/(pow(p[45], 2) + 1.0*pow(p[44], 2));
out[389] = -1.0*p[40];
out[390] = -1.0*p[41];
out[393] = -1.0*p[40];
out[394] = -1.0*p[41];
out[397] = -1.0*p[40];
out[398] = -1.0*p[41];
out[401] = -1.0*p[42];
out[402] = -1.0*p[43];
out[404] = -1.0*p[44]/(pow(p[45], 2) + 1.0*pow(p[44], 2));
out[409] = 1.0*p[45]/(pow(p[45], 2) + 1.0*pow(p[44], 2));
out[427] = 1.0/u[12];
out[430] = p[51];
out[431] = -p[50];

}

void sp_jac_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[1] = -1.0;
out[22] = -1.0;
out[43] = -1.0;
out[64] = -1.0;
out[85] = -1.0;
out[102] = -1.0;
out[119] = -1.0;
out[136] = -1.0;
out[153] = -1.0;
out[170] = -1.0;
out[187] = -1.0;
out[204] = -1.0;
out[221] = -1.0;
out[238] = -1.0;
out[255] = -1.0;
out[272] = -1.0;
out[289] = -1.0;
out[358] = 1.0;
out[359] = 1.0;
out[360] = 1.0;
out[361] = 1.0;
out[362] = 1.0;
out[363] = 1.0;
out[364] = 1.0;
out[365] = 1.0;
out[366] = -1.0;
out[368] = 1.0;
out[370] = -1.0;
out[372] = 1.0;
out[374] = -1.0;
out[376] = 1.0;
out[378] = -1.0;
out[380] = 1.0;
out[382] = 1.0;
out[383] = 1.0;
out[384] = 1.0;
out[385] = 1.0;
out[388] = -1.0;
out[391] = 1.0;
out[392] = -1.0;
out[395] = 1.0;
out[396] = -1.0;
out[399] = 1.0;
out[400] = -1.0;
out[403] = 1.0;
out[405] = 1.0;
out[406] = 1.0;
out[407] = 1.0;
out[408] = 1.0;
out[422] = -1.0;
out[428] = -1.0;
out[429] = -1.0;
out[432] = -1.0;

}

void de_jac_trap_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[1184] = 2.0*y[8]*u[2] - 2.0*y[14]*u[2] + y[24];
out[1185] = 2.0*y[9]*u[2] - 2.0*y[15]*u[2] + y[25];
out[1190] = -2.0*y[8]*u[2] + 2.0*y[14]*u[2] - y[24];
out[1191] = -2.0*y[9]*u[2] + 2.0*y[15]*u[2] - y[25];
out[1200] = y[8] - y[14];
out[1201] = y[9] - y[15];
out[1233] = 2.0*y[10]*u[6] - 2.0*y[14]*u[6] + y[26];
out[1234] = 2.0*y[11]*u[6] - 2.0*y[15]*u[6] + y[27];
out[1237] = -2.0*y[10]*u[6] + 2.0*y[14]*u[6] - y[26];
out[1238] = -2.0*y[11]*u[6] + 2.0*y[15]*u[6] - y[27];
out[1249] = y[10] - y[14];
out[1250] = y[11] - y[15];
out[1282] = 2.0*y[12]*u[10] - 2.0*y[14]*u[10] + y[28];
out[1283] = 2.0*y[13]*u[10] - 2.0*y[15]*u[10] + y[29];
out[1284] = -2.0*y[12]*u[10] + 2.0*y[14]*u[10] - y[28];
out[1285] = -2.0*y[13]*u[10] + 2.0*y[15]*u[10] - y[29];
out[1298] = y[12] - y[14];
out[1299] = y[13] - y[15];
out[1325] = -2.0*y[8]*u[3] + 2.0*y[14]*u[3] - y[25];
out[1326] = -2.0*y[9]*u[3] + 2.0*y[15]*u[3] + y[24];
out[1331] = 2.0*y[8]*u[3] - 2.0*y[14]*u[3] + y[25];
out[1332] = 2.0*y[9]*u[3] - 2.0*y[15]*u[3] - y[24];
out[1341] = y[9] - y[15];
out[1342] = -y[8] + y[14];
out[1374] = -2.0*y[10]*u[7] + 2.0*y[14]*u[7] - y[27];
out[1375] = -2.0*y[11]*u[7] + 2.0*y[15]*u[7] + y[26];
out[1378] = 2.0*y[10]*u[7] - 2.0*y[14]*u[7] + y[27];
out[1379] = 2.0*y[11]*u[7] - 2.0*y[15]*u[7] - y[26];
out[1390] = y[11] - y[15];
out[1391] = -y[10] + y[14];
out[1423] = -2.0*y[12]*u[11] + 2.0*y[14]*u[11] - y[29];
out[1424] = -2.0*y[13]*u[11] + 2.0*y[15]*u[11] + y[28];
out[1425] = 2.0*y[12]*u[11] - 2.0*y[14]*u[11] + y[29];
out[1426] = 2.0*y[13]*u[11] - 2.0*y[15]*u[11] - y[28];
out[1439] = y[13] - y[15];
out[1440] = -y[12] + y[14];
out[2022] = y[32];
out[2023] = 1.0*y[39];
out[2024] = y[33];
out[2025] = 1.0*y[40];
out[2026] = y[34];
out[2027] = 1.0*y[41];
out[2028] = y[34];
out[2029] = 1.0*y[41];
out[2054] = p[48]*y[32]*pow(pow(y[39], 2) + pow(y[32], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[32] + y[0];
out[2055] = p[48]*y[33]*pow(pow(y[40], 2) + pow(y[33], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[33] + y[2];
out[2056] = p[48]*y[34]*pow(pow(y[41], 2) + pow(y[34], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[34] + y[4] + y[6];
out[2057] = p[48]*y[35]*pow(pow(y[42], 2) + pow(y[35], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[35];
out[2061] = p[48]*y[39]*pow(pow(y[39], 2) + pow(y[32], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[39] + 1.0*y[1];
out[2062] = p[48]*y[40]*pow(pow(y[40], 2) + pow(y[33], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[40] + 1.0*y[3];
out[2063] = p[48]*y[41]*pow(pow(y[41], 2) + pow(y[34], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[41] + 1.0*y[5] + 1.0*y[7];
out[2064] = p[48]*y[42]*pow(pow(y[42], 2) + pow(y[35], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[42];

}

void de_jac_trap_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 0.5*Dt*p[52] + 1.0;
out[45] = 0.5*Dt;
out[48] = p[0] + p[32];
out[49] = -p[1] - p[33];
out[50] = p[2] + p[34];
out[51] = -p[3] - p[35];
out[52] = p[4];
out[53] = -p[5];
out[54] = p[6];
out[55] = -p[7];
out[56] = -p[0];
out[57] = p[1];
out[58] = -p[2];
out[59] = p[3];
out[60] = -p[4];
out[61] = p[5];
out[62] = -p[6];
out[63] = p[7];
out[64] = -p[32];
out[65] = p[33];
out[66] = -p[34];
out[67] = p[35];
out[95] = p[1] + p[33];
out[96] = p[0] + p[32];
out[97] = p[3] + p[35];
out[98] = p[2] + p[34];
out[99] = p[5];
out[100] = p[4];
out[101] = p[7];
out[102] = p[6];
out[103] = -p[1];
out[104] = -p[0];
out[105] = -p[3];
out[106] = -p[2];
out[107] = -p[5];
out[108] = -p[4];
out[109] = -p[7];
out[110] = -p[6];
out[111] = -p[33];
out[112] = -p[32];
out[113] = -p[35];
out[114] = -p[34];
out[142] = p[8] + p[36];
out[143] = -p[9] - p[37];
out[144] = p[10] + p[38];
out[145] = -p[11] - p[39];
out[146] = p[12];
out[147] = -p[13];
out[148] = p[14];
out[149] = -p[15];
out[150] = -p[8];
out[151] = p[9];
out[152] = -p[10];
out[153] = p[11];
out[154] = -p[12];
out[155] = p[13];
out[156] = -p[14];
out[157] = p[15];
out[158] = -p[36];
out[159] = p[37];
out[160] = -p[38];
out[161] = p[39];
out[189] = p[9] + p[37];
out[190] = p[8] + p[36];
out[191] = p[11] + p[39];
out[192] = p[10] + p[38];
out[193] = p[13];
out[194] = p[12];
out[195] = p[15];
out[196] = p[14];
out[197] = -p[9];
out[198] = -p[8];
out[199] = -p[11];
out[200] = -p[10];
out[201] = -p[13];
out[202] = -p[12];
out[203] = -p[15];
out[204] = -p[14];
out[205] = -p[37];
out[206] = -p[36];
out[207] = -p[39];
out[208] = -p[38];
out[236] = p[16];
out[237] = -p[17];
out[238] = p[18];
out[239] = -p[19];
out[240] = p[20];
out[241] = -p[21];
out[242] = p[22];
out[243] = -p[23];
out[244] = -p[16];
out[245] = p[17];
out[246] = -p[18];
out[247] = p[19];
out[248] = -p[20];
out[249] = p[21];
out[250] = -p[22];
out[251] = p[23];
out[283] = p[17];
out[284] = p[16];
out[285] = p[19];
out[286] = p[18];
out[287] = p[21];
out[288] = p[20];
out[289] = p[23];
out[290] = p[22];
out[291] = -p[17];
out[292] = -p[16];
out[293] = -p[19];
out[294] = -p[18];
out[295] = -p[21];
out[296] = -p[20];
out[297] = -p[23];
out[298] = -p[22];
out[330] = p[24];
out[331] = -p[25];
out[332] = p[26];
out[333] = -p[27];
out[334] = p[28];
out[335] = -p[29];
out[336] = p[30];
out[337] = -p[31];
out[338] = -p[24];
out[339] = p[25];
out[340] = -p[26];
out[341] = p[27];
out[342] = -p[28];
out[343] = p[29];
out[344] = -p[30];
out[345] = p[31];
out[377] = p[25];
out[378] = p[24];
out[379] = p[27];
out[380] = p[26];
out[381] = p[29];
out[382] = p[28];
out[383] = p[31];
out[384] = p[30];
out[385] = -p[25];
out[386] = -p[24];
out[387] = -p[27];
out[388] = -p[26];
out[389] = -p[29];
out[390] = -p[28];
out[391] = -p[31];
out[392] = -p[30];
out[424] = -p[0];
out[425] = p[1];
out[426] = -p[2];
out[427] = p[3];
out[428] = -p[4];
out[429] = p[5];
out[430] = -p[6];
out[431] = p[7];
out[432] = p[0];
out[433] = -p[1];
out[434] = p[2];
out[435] = -p[3];
out[436] = p[4];
out[437] = -p[5];
out[438] = p[6];
out[439] = -p[7];
out[471] = -p[1];
out[472] = -p[0];
out[473] = -p[3];
out[474] = -p[2];
out[475] = -p[5];
out[476] = -p[4];
out[477] = -p[7];
out[478] = -p[6];
out[479] = p[1];
out[480] = p[0];
out[481] = p[3];
out[482] = p[2];
out[483] = p[5];
out[484] = p[4];
out[485] = p[7];
out[486] = p[6];
out[518] = -p[8];
out[519] = p[9];
out[520] = -p[10];
out[521] = p[11];
out[522] = -p[12];
out[523] = p[13];
out[524] = -p[14];
out[525] = p[15];
out[526] = p[8];
out[527] = -p[9];
out[528] = p[10];
out[529] = -p[11];
out[530] = p[12];
out[531] = -p[13];
out[532] = p[14];
out[533] = -p[15];
out[565] = -p[9];
out[566] = -p[8];
out[567] = -p[11];
out[568] = -p[10];
out[569] = -p[13];
out[570] = -p[12];
out[571] = -p[15];
out[572] = -p[14];
out[573] = p[9];
out[574] = p[8];
out[575] = p[11];
out[576] = p[10];
out[577] = p[13];
out[578] = p[12];
out[579] = p[15];
out[580] = p[14];
out[612] = -p[16];
out[613] = p[17];
out[614] = -p[18];
out[615] = p[19];
out[616] = -p[20];
out[617] = p[21];
out[618] = -p[22];
out[619] = p[23];
out[620] = p[16];
out[621] = -p[17];
out[622] = p[18];
out[623] = -p[19];
out[624] = p[20];
out[625] = -p[21];
out[626] = p[22];
out[627] = -p[23];
out[659] = -p[17];
out[660] = -p[16];
out[661] = -p[19];
out[662] = -p[18];
out[663] = -p[21];
out[664] = -p[20];
out[665] = -p[23];
out[666] = -p[22];
out[667] = p[17];
out[668] = p[16];
out[669] = p[19];
out[670] = p[18];
out[671] = p[21];
out[672] = p[20];
out[673] = p[23];
out[674] = p[22];
out[706] = -p[24];
out[707] = p[25];
out[708] = -p[26];
out[709] = p[27];
out[710] = -p[28];
out[711] = p[29];
out[712] = -p[30];
out[713] = p[31];
out[714] = p[24];
out[715] = -p[25];
out[716] = p[26];
out[717] = -p[27];
out[718] = p[28];
out[719] = -p[29];
out[720] = p[30];
out[721] = -p[31];
out[753] = -p[25];
out[754] = -p[24];
out[755] = -p[27];
out[756] = -p[26];
out[757] = -p[29];
out[758] = -p[28];
out[759] = -p[31];
out[760] = -p[30];
out[761] = p[25];
out[762] = p[24];
out[763] = p[27];
out[764] = p[26];
out[765] = p[29];
out[766] = p[28];
out[767] = p[31];
out[768] = p[30];
out[800] = -p[32];
out[801] = p[33];
out[802] = -p[34];
out[803] = p[35];
out[816] = p[32];
out[817] = -p[33];
out[818] = p[34];
out[819] = -p[35];
out[847] = -p[33];
out[848] = -p[32];
out[849] = -p[35];
out[850] = -p[34];
out[863] = p[33];
out[864] = p[32];
out[865] = p[35];
out[866] = p[34];
out[894] = -p[36];
out[895] = p[37];
out[896] = -p[38];
out[897] = p[39];
out[910] = p[36];
out[911] = -p[37];
out[912] = p[38];
out[913] = -p[39];
out[941] = -p[37];
out[942] = -p[36];
out[943] = -p[39];
out[944] = -p[38];
out[957] = p[37];
out[958] = p[36];
out[959] = p[39];
out[960] = p[38];
out[1584] = -p[41];
out[1591] = 1.0*p[40];
out[1632] = -p[41];
out[1639] = 1.0*p[40];
out[1680] = -p[41];
out[1687] = 1.0*p[40];
out[1728] = -p[43];
out[1735] = 1.0*p[42];
out[1776] = p[45]/(pow(p[45], 2) + 1.0*pow(p[44], 2));
out[1783] = 1.0*p[44]/(pow(p[45], 2) + 1.0*pow(p[44], 2));
out[1819] = -1.0*p[40];
out[1826] = -1.0*p[41];
out[1867] = -1.0*p[40];
out[1874] = -1.0*p[41];
out[1915] = -1.0*p[40];
out[1922] = -1.0*p[41];
out[1963] = -1.0*p[42];
out[1970] = -1.0*p[43];
out[2011] = -1.0*p[44]/(pow(p[45], 2) + 1.0*pow(p[44], 2));
out[2018] = 1.0*p[45]/(pow(p[45], 2) + 1.0*pow(p[44], 2));
out[2106] = 1.0/u[12];
out[2162] = p[51];
out[2207] = -p[50];

}

void de_jac_trap_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[80] = -1.0;
out[134] = -1.0;
out[175] = -1.0;
out[229] = -1.0;
out[270] = -1.0;
out[324] = -1.0;
out[365] = -1.0;
out[419] = -1.0;
out[448] = -1.0;
out[496] = -1.0;
out[544] = -1.0;
out[592] = -1.0;
out[640] = -1.0;
out[688] = -1.0;
out[736] = -1.0;
out[784] = -1.0;
out[1482] = 1.0;
out[1484] = 1.0;
out[1486] = 1.0;
out[1488] = 1.0;
out[1530] = 1.0;
out[1532] = 1.0;
out[1534] = 1.0;
out[1536] = 1.0;
out[1552] = -1.0;
out[1588] = 1.0;
out[1601] = -1.0;
out[1635] = 1.0;
out[1650] = -1.0;
out[1682] = 1.0;
out[1699] = -1.0;
out[1729] = 1.0;
out[1772] = 1.0;
out[1773] = 1.0;
out[1774] = 1.0;
out[1775] = 1.0;
out[1788] = -1.0;
out[1830] = 1.0;
out[1837] = -1.0;
out[1877] = 1.0;
out[1886] = -1.0;
out[1924] = 1.0;
out[1935] = -1.0;
out[1971] = 1.0;
out[2014] = 1.0;
out[2015] = 1.0;
out[2016] = 1.0;
out[2017] = 1.0;
out[2059] = -1.0;
out[2107] = -1.0;
out[2160] = -1.0;
out[2208] = -1.0;

}

void sp_jac_trap_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[322] = 2.0*y[8]*u[2] - 2.0*y[14]*u[2] + y[24];
out[323] = 2.0*y[9]*u[2] - 2.0*y[15]*u[2] + y[25];
out[324] = -2.0*y[8]*u[2] + 2.0*y[14]*u[2] - y[24];
out[325] = -2.0*y[9]*u[2] + 2.0*y[15]*u[2] - y[25];
out[326] = y[8] - y[14];
out[327] = y[9] - y[15];
out[328] = 2.0*y[10]*u[6] - 2.0*y[14]*u[6] + y[26];
out[329] = 2.0*y[11]*u[6] - 2.0*y[15]*u[6] + y[27];
out[330] = -2.0*y[10]*u[6] + 2.0*y[14]*u[6] - y[26];
out[331] = -2.0*y[11]*u[6] + 2.0*y[15]*u[6] - y[27];
out[332] = y[10] - y[14];
out[333] = y[11] - y[15];
out[334] = 2.0*y[12]*u[10] - 2.0*y[14]*u[10] + y[28];
out[335] = 2.0*y[13]*u[10] - 2.0*y[15]*u[10] + y[29];
out[336] = -2.0*y[12]*u[10] + 2.0*y[14]*u[10] - y[28];
out[337] = -2.0*y[13]*u[10] + 2.0*y[15]*u[10] - y[29];
out[338] = y[12] - y[14];
out[339] = y[13] - y[15];
out[340] = -2.0*y[8]*u[3] + 2.0*y[14]*u[3] - y[25];
out[341] = -2.0*y[9]*u[3] + 2.0*y[15]*u[3] + y[24];
out[342] = 2.0*y[8]*u[3] - 2.0*y[14]*u[3] + y[25];
out[343] = 2.0*y[9]*u[3] - 2.0*y[15]*u[3] - y[24];
out[344] = y[9] - y[15];
out[345] = -y[8] + y[14];
out[346] = -2.0*y[10]*u[7] + 2.0*y[14]*u[7] - y[27];
out[347] = -2.0*y[11]*u[7] + 2.0*y[15]*u[7] + y[26];
out[348] = 2.0*y[10]*u[7] - 2.0*y[14]*u[7] + y[27];
out[349] = 2.0*y[11]*u[7] - 2.0*y[15]*u[7] - y[26];
out[350] = y[11] - y[15];
out[351] = -y[10] + y[14];
out[352] = -2.0*y[12]*u[11] + 2.0*y[14]*u[11] - y[29];
out[353] = -2.0*y[13]*u[11] + 2.0*y[15]*u[11] + y[28];
out[354] = 2.0*y[12]*u[11] - 2.0*y[14]*u[11] + y[29];
out[355] = 2.0*y[13]*u[11] - 2.0*y[15]*u[11] - y[28];
out[356] = y[13] - y[15];
out[357] = -y[12] + y[14];
out[410] = y[32];
out[411] = 1.0*y[39];
out[412] = y[33];
out[413] = 1.0*y[40];
out[414] = y[34];
out[415] = 1.0*y[41];
out[416] = y[34];
out[417] = 1.0*y[41];
out[418] = p[48]*y[32]*pow(pow(y[39], 2) + pow(y[32], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[32] + y[0];
out[419] = p[48]*y[33]*pow(pow(y[40], 2) + pow(y[33], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[33] + y[2];
out[420] = p[48]*y[34]*pow(pow(y[41], 2) + pow(y[34], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[34] + y[4] + y[6];
out[421] = p[48]*y[35]*pow(pow(y[42], 2) + pow(y[35], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[35];
out[423] = p[48]*y[39]*pow(pow(y[39], 2) + pow(y[32], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[39] + 1.0*y[1];
out[424] = p[48]*y[40]*pow(pow(y[40], 2) + pow(y[33], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[40] + 1.0*y[3];
out[425] = p[48]*y[41]*pow(pow(y[41], 2) + pow(y[34], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[41] + 1.0*y[5] + 1.0*y[7];
out[426] = p[48]*y[42]*pow(pow(y[42], 2) + pow(y[35], 2) + 9.9999999999999995e-7, -0.5) + 2.0*p[49]*y[42];

}

void sp_jac_trap_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 0.5*Dt*p[52] + 1.0;
out[1] = 0.5*Dt;
out[2] = p[0] + p[32];
out[3] = -p[1] - p[33];
out[4] = p[2] + p[34];
out[5] = -p[3] - p[35];
out[6] = p[4];
out[7] = -p[5];
out[8] = p[6];
out[9] = -p[7];
out[10] = -p[0];
out[11] = p[1];
out[12] = -p[2];
out[13] = p[3];
out[14] = -p[4];
out[15] = p[5];
out[16] = -p[6];
out[17] = p[7];
out[18] = -p[32];
out[19] = p[33];
out[20] = -p[34];
out[21] = p[35];
out[23] = p[1] + p[33];
out[24] = p[0] + p[32];
out[25] = p[3] + p[35];
out[26] = p[2] + p[34];
out[27] = p[5];
out[28] = p[4];
out[29] = p[7];
out[30] = p[6];
out[31] = -p[1];
out[32] = -p[0];
out[33] = -p[3];
out[34] = -p[2];
out[35] = -p[5];
out[36] = -p[4];
out[37] = -p[7];
out[38] = -p[6];
out[39] = -p[33];
out[40] = -p[32];
out[41] = -p[35];
out[42] = -p[34];
out[44] = p[8] + p[36];
out[45] = -p[9] - p[37];
out[46] = p[10] + p[38];
out[47] = -p[11] - p[39];
out[48] = p[12];
out[49] = -p[13];
out[50] = p[14];
out[51] = -p[15];
out[52] = -p[8];
out[53] = p[9];
out[54] = -p[10];
out[55] = p[11];
out[56] = -p[12];
out[57] = p[13];
out[58] = -p[14];
out[59] = p[15];
out[60] = -p[36];
out[61] = p[37];
out[62] = -p[38];
out[63] = p[39];
out[65] = p[9] + p[37];
out[66] = p[8] + p[36];
out[67] = p[11] + p[39];
out[68] = p[10] + p[38];
out[69] = p[13];
out[70] = p[12];
out[71] = p[15];
out[72] = p[14];
out[73] = -p[9];
out[74] = -p[8];
out[75] = -p[11];
out[76] = -p[10];
out[77] = -p[13];
out[78] = -p[12];
out[79] = -p[15];
out[80] = -p[14];
out[81] = -p[37];
out[82] = -p[36];
out[83] = -p[39];
out[84] = -p[38];
out[86] = p[16];
out[87] = -p[17];
out[88] = p[18];
out[89] = -p[19];
out[90] = p[20];
out[91] = -p[21];
out[92] = p[22];
out[93] = -p[23];
out[94] = -p[16];
out[95] = p[17];
out[96] = -p[18];
out[97] = p[19];
out[98] = -p[20];
out[99] = p[21];
out[100] = -p[22];
out[101] = p[23];
out[103] = p[17];
out[104] = p[16];
out[105] = p[19];
out[106] = p[18];
out[107] = p[21];
out[108] = p[20];
out[109] = p[23];
out[110] = p[22];
out[111] = -p[17];
out[112] = -p[16];
out[113] = -p[19];
out[114] = -p[18];
out[115] = -p[21];
out[116] = -p[20];
out[117] = -p[23];
out[118] = -p[22];
out[120] = p[24];
out[121] = -p[25];
out[122] = p[26];
out[123] = -p[27];
out[124] = p[28];
out[125] = -p[29];
out[126] = p[30];
out[127] = -p[31];
out[128] = -p[24];
out[129] = p[25];
out[130] = -p[26];
out[131] = p[27];
out[132] = -p[28];
out[133] = p[29];
out[134] = -p[30];
out[135] = p[31];
out[137] = p[25];
out[138] = p[24];
out[139] = p[27];
out[140] = p[26];
out[141] = p[29];
out[142] = p[28];
out[143] = p[31];
out[144] = p[30];
out[145] = -p[25];
out[146] = -p[24];
out[147] = -p[27];
out[148] = -p[26];
out[149] = -p[29];
out[150] = -p[28];
out[151] = -p[31];
out[152] = -p[30];
out[154] = -p[0];
out[155] = p[1];
out[156] = -p[2];
out[157] = p[3];
out[158] = -p[4];
out[159] = p[5];
out[160] = -p[6];
out[161] = p[7];
out[162] = p[0];
out[163] = -p[1];
out[164] = p[2];
out[165] = -p[3];
out[166] = p[4];
out[167] = -p[5];
out[168] = p[6];
out[169] = -p[7];
out[171] = -p[1];
out[172] = -p[0];
out[173] = -p[3];
out[174] = -p[2];
out[175] = -p[5];
out[176] = -p[4];
out[177] = -p[7];
out[178] = -p[6];
out[179] = p[1];
out[180] = p[0];
out[181] = p[3];
out[182] = p[2];
out[183] = p[5];
out[184] = p[4];
out[185] = p[7];
out[186] = p[6];
out[188] = -p[8];
out[189] = p[9];
out[190] = -p[10];
out[191] = p[11];
out[192] = -p[12];
out[193] = p[13];
out[194] = -p[14];
out[195] = p[15];
out[196] = p[8];
out[197] = -p[9];
out[198] = p[10];
out[199] = -p[11];
out[200] = p[12];
out[201] = -p[13];
out[202] = p[14];
out[203] = -p[15];
out[205] = -p[9];
out[206] = -p[8];
out[207] = -p[11];
out[208] = -p[10];
out[209] = -p[13];
out[210] = -p[12];
out[211] = -p[15];
out[212] = -p[14];
out[213] = p[9];
out[214] = p[8];
out[215] = p[11];
out[216] = p[10];
out[217] = p[13];
out[218] = p[12];
out[219] = p[15];
out[220] = p[14];
out[222] = -p[16];
out[223] = p[17];
out[224] = -p[18];
out[225] = p[19];
out[226] = -p[20];
out[227] = p[21];
out[228] = -p[22];
out[229] = p[23];
out[230] = p[16];
out[231] = -p[17];
out[232] = p[18];
out[233] = -p[19];
out[234] = p[20];
out[235] = -p[21];
out[236] = p[22];
out[237] = -p[23];
out[239] = -p[17];
out[240] = -p[16];
out[241] = -p[19];
out[242] = -p[18];
out[243] = -p[21];
out[244] = -p[20];
out[245] = -p[23];
out[246] = -p[22];
out[247] = p[17];
out[248] = p[16];
out[249] = p[19];
out[250] = p[18];
out[251] = p[21];
out[252] = p[20];
out[253] = p[23];
out[254] = p[22];
out[256] = -p[24];
out[257] = p[25];
out[258] = -p[26];
out[259] = p[27];
out[260] = -p[28];
out[261] = p[29];
out[262] = -p[30];
out[263] = p[31];
out[264] = p[24];
out[265] = -p[25];
out[266] = p[26];
out[267] = -p[27];
out[268] = p[28];
out[269] = -p[29];
out[270] = p[30];
out[271] = -p[31];
out[273] = -p[25];
out[274] = -p[24];
out[275] = -p[27];
out[276] = -p[26];
out[277] = -p[29];
out[278] = -p[28];
out[279] = -p[31];
out[280] = -p[30];
out[281] = p[25];
out[282] = p[24];
out[283] = p[27];
out[284] = p[26];
out[285] = p[29];
out[286] = p[28];
out[287] = p[31];
out[288] = p[30];
out[290] = -p[32];
out[291] = p[33];
out[292] = -p[34];
out[293] = p[35];
out[294] = p[32];
out[295] = -p[33];
out[296] = p[34];
out[297] = -p[35];
out[298] = -p[33];
out[299] = -p[32];
out[300] = -p[35];
out[301] = -p[34];
out[302] = p[33];
out[303] = p[32];
out[304] = p[35];
out[305] = p[34];
out[306] = -p[36];
out[307] = p[37];
out[308] = -p[38];
out[309] = p[39];
out[310] = p[36];
out[311] = -p[37];
out[312] = p[38];
out[313] = -p[39];
out[314] = -p[37];
out[315] = -p[36];
out[316] = -p[39];
out[317] = -p[38];
out[318] = p[37];
out[319] = p[36];
out[320] = p[39];
out[321] = p[38];
out[367] = -p[41];
out[369] = 1.0*p[40];
out[371] = -p[41];
out[373] = 1.0*p[40];
out[375] = -p[41];
out[377] = 1.0*p[40];
out[379] = -p[43];
out[381] = 1.0*p[42];
out[386] = p[45]/(pow(p[45], 2) + 1.0*pow(p[44], 2));
out[387] = 1.0*p[44]/(pow(p[45], 2) + 1.0*pow(p[44], 2));
out[389] = -1.0*p[40];
out[390] = -1.0*p[41];
out[393] = -1.0*p[40];
out[394] = -1.0*p[41];
out[397] = -1.0*p[40];
out[398] = -1.0*p[41];
out[401] = -1.0*p[42];
out[402] = -1.0*p[43];
out[404] = -1.0*p[44]/(pow(p[45], 2) + 1.0*pow(p[44], 2));
out[409] = 1.0*p[45]/(pow(p[45], 2) + 1.0*pow(p[44], 2));
out[427] = 1.0/u[12];
out[430] = p[51];
out[431] = -p[50];

}

void sp_jac_trap_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[22] = -1.0;
out[43] = -1.0;
out[64] = -1.0;
out[85] = -1.0;
out[102] = -1.0;
out[119] = -1.0;
out[136] = -1.0;
out[153] = -1.0;
out[170] = -1.0;
out[187] = -1.0;
out[204] = -1.0;
out[221] = -1.0;
out[238] = -1.0;
out[255] = -1.0;
out[272] = -1.0;
out[289] = -1.0;
out[358] = 1.0;
out[359] = 1.0;
out[360] = 1.0;
out[361] = 1.0;
out[362] = 1.0;
out[363] = 1.0;
out[364] = 1.0;
out[365] = 1.0;
out[366] = -1.0;
out[368] = 1.0;
out[370] = -1.0;
out[372] = 1.0;
out[374] = -1.0;
out[376] = 1.0;
out[378] = -1.0;
out[380] = 1.0;
out[382] = 1.0;
out[383] = 1.0;
out[384] = 1.0;
out[385] = 1.0;
out[388] = -1.0;
out[391] = 1.0;
out[392] = -1.0;
out[395] = 1.0;
out[396] = -1.0;
out[399] = 1.0;
out[400] = -1.0;
out[403] = 1.0;
out[405] = 1.0;
out[406] = 1.0;
out[407] = 1.0;
out[408] = 1.0;
out[422] = -1.0;
out[428] = -1.0;
out[429] = -1.0;
out[432] = -1.0;

}

void de_Fu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Fu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Fu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[22] = 1.0;

}

void de_Gu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[554] = pow(y[9], 2) - 2.0*y[9]*y[15] + pow(y[8], 2) - 2.0*y[8]*y[14] + pow(y[15], 2) + pow(y[14], 2);
out[581] = pow(y[11], 2) - 2.0*y[11]*y[15] + pow(y[10], 2) - 2.0*y[10]*y[14] + pow(y[15], 2) + pow(y[14], 2);
out[608] = pow(y[13], 2) - 2.0*y[13]*y[15] + pow(y[12], 2) - 2.0*y[12]*y[14] + pow(y[15], 2) + pow(y[14], 2);
out[624] = -1.0*pow(y[9], 2) + 2.0*y[9]*y[15] - 1.0*pow(y[8], 2) + 2.0*y[8]*y[14] - 1.0*pow(y[15], 2) - 1.0*pow(y[14], 2);
out[651] = -1.0*pow(y[11], 2) + 2.0*y[11]*y[15] - 1.0*pow(y[10], 2) + 2.0*y[10]*y[14] - 1.0*pow(y[15], 2) - 1.0*pow(y[14], 2);
out[678] = -1.0*pow(y[13], 2) + 2.0*y[13]*y[15] - 1.0*pow(y[12], 2) + 2.0*y[12]*y[14] - 1.0*pow(y[15], 2) - 1.0*pow(y[14], 2);
out[1001] = -y[37]/pow(u[12], 2);

}

void de_Gu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[748] = 0.40824829046386307*u[13]*cos(u[17] + u[18]);
out[749] = 0.40824829046386307*u[12]*cos(u[17] + u[18]);
out[753] = -0.40824829046386307*u[13]*u[12]*sin(u[17] + u[18]);
out[754] = -0.40824829046386307*u[13]*u[12]*sin(u[17] + u[18]);
out[771] = 0.40824829046386307*u[14]*cos(u[17] + u[19] - 2.0943951023931953);
out[773] = 0.40824829046386307*u[12]*cos(u[17] + u[19] - 2.0943951023931953);
out[776] = -0.40824829046386307*u[14]*u[12]*sin(u[17] + u[19] - 2.0943951023931953);
out[778] = -0.40824829046386307*u[14]*u[12]*sin(u[17] + u[19] - 2.0943951023931953);
out[794] = 0.40824829046386307*u[15]*cos(u[17] + u[20] - 4.1887902047863905);
out[797] = 0.40824829046386307*u[12]*cos(u[17] + u[20] - 4.1887902047863905);
out[799] = -0.40824829046386307*u[15]*u[12]*sin(u[17] + u[20] - 4.1887902047863905);
out[802] = -0.40824829046386307*u[15]*u[12]*sin(u[17] + u[20] - 4.1887902047863905);
out[817] = 0.40824829046386307*u[16]*cos(u[21]);
out[821] = 0.40824829046386307*u[12]*cos(u[21]);
out[826] = -0.40824829046386307*u[16]*u[12]*sin(u[21]);
out[863] = 0.40824829046386307*u[13]*sin(u[17] + u[18]);
out[864] = 0.40824829046386307*u[12]*sin(u[17] + u[18]);
out[868] = 0.40824829046386307*u[13]*u[12]*cos(u[17] + u[18]);
out[869] = 0.40824829046386307*u[13]*u[12]*cos(u[17] + u[18]);
out[886] = 0.40824829046386307*u[14]*sin(u[17] + u[19] - 2.0943951023931953);
out[888] = 0.40824829046386307*u[12]*sin(u[17] + u[19] - 2.0943951023931953);
out[891] = 0.40824829046386307*u[14]*u[12]*cos(u[17] + u[19] - 2.0943951023931953);
out[893] = 0.40824829046386307*u[14]*u[12]*cos(u[17] + u[19] - 2.0943951023931953);
out[909] = 0.40824829046386307*u[15]*sin(u[17] + u[20] - 4.1887902047863905);
out[912] = 0.40824829046386307*u[12]*sin(u[17] + u[20] - 4.1887902047863905);
out[914] = 0.40824829046386307*u[15]*u[12]*cos(u[17] + u[20] - 4.1887902047863905);
out[917] = 0.40824829046386307*u[15]*u[12]*cos(u[17] + u[20] - 4.1887902047863905);
out[932] = 0.40824829046386307*u[16]*sin(u[21]);
out[936] = 0.40824829046386307*u[12]*sin(u[21]);
out[941] = 0.40824829046386307*u[16]*u[12]*cos(u[21]);

}

void de_Gu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[552] = 1.0;
out[579] = 1.0;
out[606] = 1.0;
out[622] = 1.0;
out[649] = 1.0;
out[676] = 1.0;

}

void de_Hx_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hx_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hx_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[24] = 1.0;

}

void de_Hy_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[584] = y[32]*pow(1.0*pow(y[39], 2) + pow(y[32], 2), -0.5);
out[591] = 1.0*y[39]*pow(1.0*pow(y[39], 2) + pow(y[32], 2), -0.5);
out[631] = y[33]*pow(1.0*pow(y[40], 2) + pow(y[33], 2), -0.5);
out[638] = 1.0*y[40]*pow(1.0*pow(y[40], 2) + pow(y[33], 2), -0.5);
out[678] = y[34]*pow(1.0*pow(y[41], 2) + pow(y[34], 2), -0.5);
out[685] = 1.0*y[41]*pow(1.0*pow(y[41], 2) + pow(y[34], 2), -0.5);
out[725] = y[35]*pow(1.0*pow(y[42], 2) + pow(y[35], 2), -0.5);
out[732] = 1.0*y[42]*pow(1.0*pow(y[42], 2) + pow(y[35], 2), -0.5);
out[736] = 0.33333333333333331*y[32] - 0.28867513459481287*y[40] - 0.16666666666666657*y[33] + 0.28867513459481275*y[41] - 0.16666666666666677*y[34];
out[737] = 0.33333333333333331*y[39] - 0.16666666666666657*y[40] + 0.28867513459481287*y[33] - 0.16666666666666677*y[41] - 0.28867513459481275*y[34];
out[738] = 0.28867513459481287*y[39] - 0.16666666666666657*y[32] + 0.33333333333333326*y[33] - 0.28867513459481281*y[41] - 0.16666666666666652*y[34];
out[739] = -0.16666666666666657*y[39] - 0.28867513459481287*y[32] + 0.33333333333333326*y[40] - 0.16666666666666652*y[41] + 0.28867513459481281*y[34];
out[740] = -0.28867513459481275*y[39] - 0.16666666666666677*y[32] + 0.28867513459481281*y[40] - 0.16666666666666652*y[33] + 0.33333333333333326*y[34];
out[741] = -0.16666666666666677*y[39] + 0.28867513459481275*y[32] - 0.16666666666666652*y[40] - 0.28867513459481281*y[33] + 0.33333333333333326*y[41];
out[768] = 0.33333333333333331*y[0] - 0.28867513459481287*y[3] - 0.16666666666666657*y[2] + 0.28867513459481275*y[5] - 0.16666666666666677*y[4];
out[769] = 0.28867513459481287*y[1] - 0.16666666666666657*y[0] + 0.33333333333333326*y[2] - 0.28867513459481281*y[5] - 0.16666666666666652*y[4];
out[770] = -0.28867513459481275*y[1] - 0.16666666666666677*y[0] + 0.28867513459481281*y[3] - 0.16666666666666652*y[2] + 0.33333333333333326*y[4];
out[775] = 0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4];
out[776] = -0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4];
out[777] = -0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5];
out[782] = 0.33333333333333331*y[32] + 0.28867513459481275*y[40] - 0.16666666666666677*y[33] - 0.28867513459481287*y[41] - 0.16666666666666657*y[34];
out[783] = 0.33333333333333331*y[39] - 0.16666666666666677*y[40] - 0.28867513459481275*y[33] - 0.16666666666666657*y[41] + 0.28867513459481287*y[34];
out[784] = -0.28867513459481275*y[39] - 0.16666666666666677*y[32] + 0.33333333333333326*y[33] + 0.28867513459481281*y[41] - 0.16666666666666652*y[34];
out[785] = -0.16666666666666677*y[39] + 0.28867513459481275*y[32] + 0.33333333333333326*y[40] - 0.16666666666666652*y[41] - 0.28867513459481281*y[34];
out[786] = 0.28867513459481287*y[39] - 0.16666666666666657*y[32] - 0.28867513459481281*y[40] - 0.16666666666666652*y[33] + 0.33333333333333326*y[34];
out[787] = -0.16666666666666657*y[39] - 0.28867513459481287*y[32] - 0.16666666666666652*y[40] + 0.28867513459481281*y[33] + 0.33333333333333326*y[41];
out[814] = 0.33333333333333331*y[0] + 0.28867513459481275*y[3] - 0.16666666666666677*y[2] - 0.28867513459481287*y[5] - 0.16666666666666657*y[4];
out[815] = -0.28867513459481275*y[1] - 0.16666666666666677*y[0] + 0.33333333333333326*y[2] + 0.28867513459481281*y[5] - 0.16666666666666652*y[4];
out[816] = 0.28867513459481287*y[1] - 0.16666666666666657*y[0] - 0.28867513459481281*y[3] - 0.16666666666666652*y[2] + 0.33333333333333326*y[4];
out[821] = 0.33333333333333331*y[1] - 0.16666666666666677*y[3] - 0.28867513459481275*y[2] - 0.16666666666666657*y[5] + 0.28867513459481287*y[4];
out[822] = -0.16666666666666677*y[1] + 0.28867513459481275*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] - 0.28867513459481281*y[4];
out[823] = -0.16666666666666657*y[1] - 0.28867513459481287*y[0] - 0.16666666666666652*y[3] + 0.28867513459481281*y[2] + 0.33333333333333326*y[5];
out[828] = 0.33333333333333331*y[32] + 0.33333333333333331*y[33] + 0.33333333333333331*y[34];
out[829] = 0.33333333333333331*y[39] + 0.33333333333333331*y[40] + 0.33333333333333331*y[41];
out[830] = 0.33333333333333331*y[32] + 0.33333333333333331*y[33] + 0.33333333333333331*y[34];
out[831] = 0.33333333333333331*y[39] + 0.33333333333333331*y[40] + 0.33333333333333331*y[41];
out[832] = 0.33333333333333331*y[32] + 0.33333333333333331*y[33] + 0.33333333333333331*y[34];
out[833] = 0.33333333333333331*y[39] + 0.33333333333333331*y[40] + 0.33333333333333331*y[41];
out[860] = 0.33333333333333331*y[0] + 0.33333333333333331*y[2] + 0.33333333333333331*y[4];
out[861] = 0.33333333333333331*y[0] + 0.33333333333333331*y[2] + 0.33333333333333331*y[4];
out[862] = 0.33333333333333331*y[0] + 0.33333333333333331*y[2] + 0.33333333333333331*y[4];
out[867] = 0.33333333333333331*y[1] + 0.33333333333333331*y[3] + 0.33333333333333331*y[5];
out[868] = 0.33333333333333331*y[1] + 0.33333333333333331*y[3] + 0.33333333333333331*y[5];
out[869] = 0.33333333333333331*y[1] + 0.33333333333333331*y[3] + 0.33333333333333331*y[5];

}

void de_Hy_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = p[0];
out[1] = -p[1];
out[2] = p[2];
out[3] = -p[3];
out[4] = p[4];
out[5] = -p[5];
out[6] = p[6];
out[7] = -p[7];
out[8] = -p[0];
out[9] = p[1];
out[10] = -p[2];
out[11] = p[3];
out[12] = -p[4];
out[13] = p[5];
out[14] = -p[6];
out[15] = p[7];
out[46] = p[1];
out[47] = p[0];
out[48] = p[3];
out[49] = p[2];
out[50] = p[5];
out[51] = p[4];
out[52] = p[7];
out[53] = p[6];
out[54] = -p[1];
out[55] = -p[0];
out[56] = -p[3];
out[57] = -p[2];
out[58] = -p[5];
out[59] = -p[4];
out[60] = -p[7];
out[61] = -p[6];
out[92] = p[8];
out[93] = -p[9];
out[94] = p[10];
out[95] = -p[11];
out[96] = p[12];
out[97] = -p[13];
out[98] = p[14];
out[99] = -p[15];
out[100] = -p[8];
out[101] = p[9];
out[102] = -p[10];
out[103] = p[11];
out[104] = -p[12];
out[105] = p[13];
out[106] = -p[14];
out[107] = p[15];
out[138] = p[9];
out[139] = p[8];
out[140] = p[11];
out[141] = p[10];
out[142] = p[13];
out[143] = p[12];
out[144] = p[15];
out[145] = p[14];
out[146] = -p[9];
out[147] = -p[8];
out[148] = -p[11];
out[149] = -p[10];
out[150] = -p[13];
out[151] = -p[12];
out[152] = -p[15];
out[153] = -p[14];
out[184] = p[16];
out[185] = -p[17];
out[186] = p[18];
out[187] = -p[19];
out[188] = p[20];
out[189] = -p[21];
out[190] = p[22];
out[191] = -p[23];
out[192] = -p[16];
out[193] = p[17];
out[194] = -p[18];
out[195] = p[19];
out[196] = -p[20];
out[197] = p[21];
out[198] = -p[22];
out[199] = p[23];
out[230] = p[17];
out[231] = p[16];
out[232] = p[19];
out[233] = p[18];
out[234] = p[21];
out[235] = p[20];
out[236] = p[23];
out[237] = p[22];
out[238] = -p[17];
out[239] = -p[16];
out[240] = -p[19];
out[241] = -p[18];
out[242] = -p[21];
out[243] = -p[20];
out[244] = -p[23];
out[245] = -p[22];
out[276] = p[24];
out[277] = -p[25];
out[278] = p[26];
out[279] = -p[27];
out[280] = p[28];
out[281] = -p[29];
out[282] = p[30];
out[283] = -p[31];
out[284] = -p[24];
out[285] = p[25];
out[286] = -p[26];
out[287] = p[27];
out[288] = -p[28];
out[289] = p[29];
out[290] = -p[30];
out[291] = p[31];
out[322] = p[25];
out[323] = p[24];
out[324] = p[27];
out[325] = p[26];
out[326] = p[29];
out[327] = p[28];
out[328] = p[31];
out[329] = p[30];
out[330] = -p[25];
out[331] = -p[24];
out[332] = -p[27];
out[333] = -p[26];
out[334] = -p[29];
out[335] = -p[28];
out[336] = -p[31];
out[337] = -p[30];
out[368] = p[32];
out[369] = -p[33];
out[370] = p[34];
out[371] = -p[35];
out[384] = -p[32];
out[385] = p[33];
out[386] = -p[34];
out[387] = p[35];
out[414] = p[33];
out[415] = p[32];
out[416] = p[35];
out[417] = p[34];
out[430] = -p[33];
out[431] = -p[32];
out[432] = -p[35];
out[433] = -p[34];
out[460] = p[36];
out[461] = -p[37];
out[462] = p[38];
out[463] = -p[39];
out[476] = -p[36];
out[477] = p[37];
out[478] = -p[38];
out[479] = p[39];
out[506] = p[37];
out[507] = p[36];
out[508] = p[39];
out[509] = p[38];
out[522] = -p[37];
out[523] = -p[36];
out[524] = -p[39];
out[525] = -p[38];

}

void de_Hy_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[450] = 1.0;
out[474] = 1.0;
out[498] = 1.0;
out[522] = 1.0;
out[546] = 1.0;
out[597] = 1.0;

}

void sp_Fu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Fu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Fu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;

}

void sp_Gu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[1] = pow(y[9], 2) - 2.0*y[9]*y[15] + pow(y[8], 2) - 2.0*y[8]*y[14] + pow(y[15], 2) + pow(y[14], 2);
out[3] = pow(y[11], 2) - 2.0*y[11]*y[15] + pow(y[10], 2) - 2.0*y[10]*y[14] + pow(y[15], 2) + pow(y[14], 2);
out[5] = pow(y[13], 2) - 2.0*y[13]*y[15] + pow(y[12], 2) - 2.0*y[12]*y[14] + pow(y[15], 2) + pow(y[14], 2);
out[7] = -1.0*pow(y[9], 2) + 2.0*y[9]*y[15] - 1.0*pow(y[8], 2) + 2.0*y[8]*y[14] - 1.0*pow(y[15], 2) - 1.0*pow(y[14], 2);
out[9] = -1.0*pow(y[11], 2) + 2.0*y[11]*y[15] - 1.0*pow(y[10], 2) + 2.0*y[10]*y[14] - 1.0*pow(y[15], 2) - 1.0*pow(y[14], 2);
out[11] = -1.0*pow(y[13], 2) + 2.0*y[13]*y[15] - 1.0*pow(y[12], 2) + 2.0*y[12]*y[14] - 1.0*pow(y[15], 2) - 1.0*pow(y[14], 2);
out[42] = -y[37]/pow(u[12], 2);

}

void sp_Gu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[12] = 0.40824829046386307*u[13]*cos(u[17] + u[18]);
out[13] = 0.40824829046386307*u[12]*cos(u[17] + u[18]);
out[14] = -0.40824829046386307*u[13]*u[12]*sin(u[17] + u[18]);
out[15] = -0.40824829046386307*u[13]*u[12]*sin(u[17] + u[18]);
out[16] = 0.40824829046386307*u[14]*cos(u[17] + u[19] - 2.0943951023931953);
out[17] = 0.40824829046386307*u[12]*cos(u[17] + u[19] - 2.0943951023931953);
out[18] = -0.40824829046386307*u[14]*u[12]*sin(u[17] + u[19] - 2.0943951023931953);
out[19] = -0.40824829046386307*u[14]*u[12]*sin(u[17] + u[19] - 2.0943951023931953);
out[20] = 0.40824829046386307*u[15]*cos(u[17] + u[20] - 4.1887902047863905);
out[21] = 0.40824829046386307*u[12]*cos(u[17] + u[20] - 4.1887902047863905);
out[22] = -0.40824829046386307*u[15]*u[12]*sin(u[17] + u[20] - 4.1887902047863905);
out[23] = -0.40824829046386307*u[15]*u[12]*sin(u[17] + u[20] - 4.1887902047863905);
out[24] = 0.40824829046386307*u[16]*cos(u[21]);
out[25] = 0.40824829046386307*u[12]*cos(u[21]);
out[26] = -0.40824829046386307*u[16]*u[12]*sin(u[21]);
out[27] = 0.40824829046386307*u[13]*sin(u[17] + u[18]);
out[28] = 0.40824829046386307*u[12]*sin(u[17] + u[18]);
out[29] = 0.40824829046386307*u[13]*u[12]*cos(u[17] + u[18]);
out[30] = 0.40824829046386307*u[13]*u[12]*cos(u[17] + u[18]);
out[31] = 0.40824829046386307*u[14]*sin(u[17] + u[19] - 2.0943951023931953);
out[32] = 0.40824829046386307*u[12]*sin(u[17] + u[19] - 2.0943951023931953);
out[33] = 0.40824829046386307*u[14]*u[12]*cos(u[17] + u[19] - 2.0943951023931953);
out[34] = 0.40824829046386307*u[14]*u[12]*cos(u[17] + u[19] - 2.0943951023931953);
out[35] = 0.40824829046386307*u[15]*sin(u[17] + u[20] - 4.1887902047863905);
out[36] = 0.40824829046386307*u[12]*sin(u[17] + u[20] - 4.1887902047863905);
out[37] = 0.40824829046386307*u[15]*u[12]*cos(u[17] + u[20] - 4.1887902047863905);
out[38] = 0.40824829046386307*u[15]*u[12]*cos(u[17] + u[20] - 4.1887902047863905);
out[39] = 0.40824829046386307*u[16]*sin(u[21]);
out[40] = 0.40824829046386307*u[12]*sin(u[21]);
out[41] = 0.40824829046386307*u[16]*u[12]*cos(u[21]);

}

void sp_Gu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;
out[2] = 1.0;
out[4] = 1.0;
out[6] = 1.0;
out[8] = 1.0;
out[10] = 1.0;

}

void sp_Hx_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hx_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hx_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;

}

void sp_Hy_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[160] = y[32]*pow(1.0*pow(y[39], 2) + pow(y[32], 2), -0.5);
out[161] = 1.0*y[39]*pow(1.0*pow(y[39], 2) + pow(y[32], 2), -0.5);
out[162] = y[33]*pow(1.0*pow(y[40], 2) + pow(y[33], 2), -0.5);
out[163] = 1.0*y[40]*pow(1.0*pow(y[40], 2) + pow(y[33], 2), -0.5);
out[164] = y[34]*pow(1.0*pow(y[41], 2) + pow(y[34], 2), -0.5);
out[165] = 1.0*y[41]*pow(1.0*pow(y[41], 2) + pow(y[34], 2), -0.5);
out[166] = y[35]*pow(1.0*pow(y[42], 2) + pow(y[35], 2), -0.5);
out[167] = 1.0*y[42]*pow(1.0*pow(y[42], 2) + pow(y[35], 2), -0.5);
out[168] = 0.33333333333333331*y[32] - 0.28867513459481287*y[40] - 0.16666666666666657*y[33] + 0.28867513459481275*y[41] - 0.16666666666666677*y[34];
out[169] = 0.33333333333333331*y[39] - 0.16666666666666657*y[40] + 0.28867513459481287*y[33] - 0.16666666666666677*y[41] - 0.28867513459481275*y[34];
out[170] = 0.28867513459481287*y[39] - 0.16666666666666657*y[32] + 0.33333333333333326*y[33] - 0.28867513459481281*y[41] - 0.16666666666666652*y[34];
out[171] = -0.16666666666666657*y[39] - 0.28867513459481287*y[32] + 0.33333333333333326*y[40] - 0.16666666666666652*y[41] + 0.28867513459481281*y[34];
out[172] = -0.28867513459481275*y[39] - 0.16666666666666677*y[32] + 0.28867513459481281*y[40] - 0.16666666666666652*y[33] + 0.33333333333333326*y[34];
out[173] = -0.16666666666666677*y[39] + 0.28867513459481275*y[32] - 0.16666666666666652*y[40] - 0.28867513459481281*y[33] + 0.33333333333333326*y[41];
out[174] = 0.33333333333333331*y[0] - 0.28867513459481287*y[3] - 0.16666666666666657*y[2] + 0.28867513459481275*y[5] - 0.16666666666666677*y[4];
out[175] = 0.28867513459481287*y[1] - 0.16666666666666657*y[0] + 0.33333333333333326*y[2] - 0.28867513459481281*y[5] - 0.16666666666666652*y[4];
out[176] = -0.28867513459481275*y[1] - 0.16666666666666677*y[0] + 0.28867513459481281*y[3] - 0.16666666666666652*y[2] + 0.33333333333333326*y[4];
out[177] = 0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4];
out[178] = -0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4];
out[179] = -0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5];
out[180] = 0.33333333333333331*y[32] + 0.28867513459481275*y[40] - 0.16666666666666677*y[33] - 0.28867513459481287*y[41] - 0.16666666666666657*y[34];
out[181] = 0.33333333333333331*y[39] - 0.16666666666666677*y[40] - 0.28867513459481275*y[33] - 0.16666666666666657*y[41] + 0.28867513459481287*y[34];
out[182] = -0.28867513459481275*y[39] - 0.16666666666666677*y[32] + 0.33333333333333326*y[33] + 0.28867513459481281*y[41] - 0.16666666666666652*y[34];
out[183] = -0.16666666666666677*y[39] + 0.28867513459481275*y[32] + 0.33333333333333326*y[40] - 0.16666666666666652*y[41] - 0.28867513459481281*y[34];
out[184] = 0.28867513459481287*y[39] - 0.16666666666666657*y[32] - 0.28867513459481281*y[40] - 0.16666666666666652*y[33] + 0.33333333333333326*y[34];
out[185] = -0.16666666666666657*y[39] - 0.28867513459481287*y[32] - 0.16666666666666652*y[40] + 0.28867513459481281*y[33] + 0.33333333333333326*y[41];
out[186] = 0.33333333333333331*y[0] + 0.28867513459481275*y[3] - 0.16666666666666677*y[2] - 0.28867513459481287*y[5] - 0.16666666666666657*y[4];
out[187] = -0.28867513459481275*y[1] - 0.16666666666666677*y[0] + 0.33333333333333326*y[2] + 0.28867513459481281*y[5] - 0.16666666666666652*y[4];
out[188] = 0.28867513459481287*y[1] - 0.16666666666666657*y[0] - 0.28867513459481281*y[3] - 0.16666666666666652*y[2] + 0.33333333333333326*y[4];
out[189] = 0.33333333333333331*y[1] - 0.16666666666666677*y[3] - 0.28867513459481275*y[2] - 0.16666666666666657*y[5] + 0.28867513459481287*y[4];
out[190] = -0.16666666666666677*y[1] + 0.28867513459481275*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] - 0.28867513459481281*y[4];
out[191] = -0.16666666666666657*y[1] - 0.28867513459481287*y[0] - 0.16666666666666652*y[3] + 0.28867513459481281*y[2] + 0.33333333333333326*y[5];
out[192] = 0.33333333333333331*y[32] + 0.33333333333333331*y[33] + 0.33333333333333331*y[34];
out[193] = 0.33333333333333331*y[39] + 0.33333333333333331*y[40] + 0.33333333333333331*y[41];
out[194] = 0.33333333333333331*y[32] + 0.33333333333333331*y[33] + 0.33333333333333331*y[34];
out[195] = 0.33333333333333331*y[39] + 0.33333333333333331*y[40] + 0.33333333333333331*y[41];
out[196] = 0.33333333333333331*y[32] + 0.33333333333333331*y[33] + 0.33333333333333331*y[34];
out[197] = 0.33333333333333331*y[39] + 0.33333333333333331*y[40] + 0.33333333333333331*y[41];
out[198] = 0.33333333333333331*y[0] + 0.33333333333333331*y[2] + 0.33333333333333331*y[4];
out[199] = 0.33333333333333331*y[0] + 0.33333333333333331*y[2] + 0.33333333333333331*y[4];
out[200] = 0.33333333333333331*y[0] + 0.33333333333333331*y[2] + 0.33333333333333331*y[4];
out[201] = 0.33333333333333331*y[1] + 0.33333333333333331*y[3] + 0.33333333333333331*y[5];
out[202] = 0.33333333333333331*y[1] + 0.33333333333333331*y[3] + 0.33333333333333331*y[5];
out[203] = 0.33333333333333331*y[1] + 0.33333333333333331*y[3] + 0.33333333333333331*y[5];

}

void sp_Hy_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = p[0];
out[1] = -p[1];
out[2] = p[2];
out[3] = -p[3];
out[4] = p[4];
out[5] = -p[5];
out[6] = p[6];
out[7] = -p[7];
out[8] = -p[0];
out[9] = p[1];
out[10] = -p[2];
out[11] = p[3];
out[12] = -p[4];
out[13] = p[5];
out[14] = -p[6];
out[15] = p[7];
out[16] = p[1];
out[17] = p[0];
out[18] = p[3];
out[19] = p[2];
out[20] = p[5];
out[21] = p[4];
out[22] = p[7];
out[23] = p[6];
out[24] = -p[1];
out[25] = -p[0];
out[26] = -p[3];
out[27] = -p[2];
out[28] = -p[5];
out[29] = -p[4];
out[30] = -p[7];
out[31] = -p[6];
out[32] = p[8];
out[33] = -p[9];
out[34] = p[10];
out[35] = -p[11];
out[36] = p[12];
out[37] = -p[13];
out[38] = p[14];
out[39] = -p[15];
out[40] = -p[8];
out[41] = p[9];
out[42] = -p[10];
out[43] = p[11];
out[44] = -p[12];
out[45] = p[13];
out[46] = -p[14];
out[47] = p[15];
out[48] = p[9];
out[49] = p[8];
out[50] = p[11];
out[51] = p[10];
out[52] = p[13];
out[53] = p[12];
out[54] = p[15];
out[55] = p[14];
out[56] = -p[9];
out[57] = -p[8];
out[58] = -p[11];
out[59] = -p[10];
out[60] = -p[13];
out[61] = -p[12];
out[62] = -p[15];
out[63] = -p[14];
out[64] = p[16];
out[65] = -p[17];
out[66] = p[18];
out[67] = -p[19];
out[68] = p[20];
out[69] = -p[21];
out[70] = p[22];
out[71] = -p[23];
out[72] = -p[16];
out[73] = p[17];
out[74] = -p[18];
out[75] = p[19];
out[76] = -p[20];
out[77] = p[21];
out[78] = -p[22];
out[79] = p[23];
out[80] = p[17];
out[81] = p[16];
out[82] = p[19];
out[83] = p[18];
out[84] = p[21];
out[85] = p[20];
out[86] = p[23];
out[87] = p[22];
out[88] = -p[17];
out[89] = -p[16];
out[90] = -p[19];
out[91] = -p[18];
out[92] = -p[21];
out[93] = -p[20];
out[94] = -p[23];
out[95] = -p[22];
out[96] = p[24];
out[97] = -p[25];
out[98] = p[26];
out[99] = -p[27];
out[100] = p[28];
out[101] = -p[29];
out[102] = p[30];
out[103] = -p[31];
out[104] = -p[24];
out[105] = p[25];
out[106] = -p[26];
out[107] = p[27];
out[108] = -p[28];
out[109] = p[29];
out[110] = -p[30];
out[111] = p[31];
out[112] = p[25];
out[113] = p[24];
out[114] = p[27];
out[115] = p[26];
out[116] = p[29];
out[117] = p[28];
out[118] = p[31];
out[119] = p[30];
out[120] = -p[25];
out[121] = -p[24];
out[122] = -p[27];
out[123] = -p[26];
out[124] = -p[29];
out[125] = -p[28];
out[126] = -p[31];
out[127] = -p[30];
out[128] = p[32];
out[129] = -p[33];
out[130] = p[34];
out[131] = -p[35];
out[132] = -p[32];
out[133] = p[33];
out[134] = -p[34];
out[135] = p[35];
out[136] = p[33];
out[137] = p[32];
out[138] = p[35];
out[139] = p[34];
out[140] = -p[33];
out[141] = -p[32];
out[142] = -p[35];
out[143] = -p[34];
out[144] = p[36];
out[145] = -p[37];
out[146] = p[38];
out[147] = -p[39];
out[148] = -p[36];
out[149] = p[37];
out[150] = -p[38];
out[151] = p[39];
out[152] = p[37];
out[153] = p[36];
out[154] = p[39];
out[155] = p[38];
out[156] = -p[37];
out[157] = -p[36];
out[158] = -p[39];
out[159] = -p[38];

}

void sp_Hy_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;
out[1] = 1.0;
out[2] = 1.0;
out[3] = 1.0;
out[4] = 1.0;
out[5] = 1.0;

}



/************************************************************/

static void *_cffi_types[] = {
/*  0 */ _CFFI_OP(_CFFI_OP_FUNCTION, 8), // void()(double *, double *, double *, double *, double *, double)
/*  1 */ _CFFI_OP(_CFFI_OP_POINTER, 6), // double *
/*  2 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  3 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  4 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  5 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  6 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14), // double
/*  7 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  8 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 0), // void
};

static void _cffi_d_de_Fu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Fu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Fu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Fu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Fu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Fu_run_num_eval _cffi_d_de_Fu_run_num_eval
#endif

static void _cffi_d_de_Fu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Fu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Fu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Fu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Fu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Fu_run_up_eval _cffi_d_de_Fu_run_up_eval
#endif

static void _cffi_d_de_Fu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Fu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Fu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Fu_run_xy_eval _cffi_d_de_Fu_run_xy_eval
#endif

static void _cffi_d_de_Gu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Gu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Gu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Gu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Gu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Gu_run_num_eval _cffi_d_de_Gu_run_num_eval
#endif

static void _cffi_d_de_Gu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Gu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Gu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Gu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Gu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Gu_run_up_eval _cffi_d_de_Gu_run_up_eval
#endif

static void _cffi_d_de_Gu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Gu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Gu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Gu_run_xy_eval _cffi_d_de_Gu_run_xy_eval
#endif

static void _cffi_d_de_Hu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hu_run_num_eval _cffi_d_de_Hu_run_num_eval
#endif

static void _cffi_d_de_Hu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hu_run_up_eval _cffi_d_de_Hu_run_up_eval
#endif

static void _cffi_d_de_Hu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hu_run_xy_eval _cffi_d_de_Hu_run_xy_eval
#endif

static void _cffi_d_de_Hx_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hx_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hx_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hx_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hx_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hx_run_num_eval _cffi_d_de_Hx_run_num_eval
#endif

static void _cffi_d_de_Hx_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hx_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hx_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hx_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hx_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hx_run_up_eval _cffi_d_de_Hx_run_up_eval
#endif

static void _cffi_d_de_Hx_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hx_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hx_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hx_run_xy_eval _cffi_d_de_Hx_run_xy_eval
#endif

static void _cffi_d_de_Hy_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hy_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hy_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hy_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hy_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hy_run_num_eval _cffi_d_de_Hy_run_num_eval
#endif

static void _cffi_d_de_Hy_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hy_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hy_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hy_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hy_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hy_run_up_eval _cffi_d_de_Hy_run_up_eval
#endif

static void _cffi_d_de_Hy_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hy_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hy_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hy_run_xy_eval _cffi_d_de_Hy_run_xy_eval
#endif

static void _cffi_d_de_jac_ini_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_ini_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_ini_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_ini_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_ini_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_ini_num_eval _cffi_d_de_jac_ini_num_eval
#endif

static void _cffi_d_de_jac_ini_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_ini_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_ini_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_ini_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_ini_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_ini_up_eval _cffi_d_de_jac_ini_up_eval
#endif

static void _cffi_d_de_jac_ini_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_ini_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_ini_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_ini_xy_eval _cffi_d_de_jac_ini_xy_eval
#endif

static void _cffi_d_de_jac_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_num_eval _cffi_d_de_jac_run_num_eval
#endif

static void _cffi_d_de_jac_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_up_eval _cffi_d_de_jac_run_up_eval
#endif

static void _cffi_d_de_jac_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_xy_eval _cffi_d_de_jac_run_xy_eval
#endif

static void _cffi_d_de_jac_trap_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_trap_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_trap_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_trap_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_trap_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_trap_num_eval _cffi_d_de_jac_trap_num_eval
#endif

static void _cffi_d_de_jac_trap_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_trap_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_trap_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_trap_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_trap_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_trap_up_eval _cffi_d_de_jac_trap_up_eval
#endif

static void _cffi_d_de_jac_trap_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_trap_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_trap_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_trap_xy_eval _cffi_d_de_jac_trap_xy_eval
#endif

static void _cffi_d_f_ini_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  f_ini_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_f_ini_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "f_ini_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { f_ini_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_f_ini_eval _cffi_d_f_ini_eval
#endif

static void _cffi_d_f_run_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  f_run_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_f_run_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "f_run_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { f_run_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_f_run_eval _cffi_d_f_run_eval
#endif

static void _cffi_d_g_ini_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  g_ini_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_g_ini_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "g_ini_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { g_ini_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_g_ini_eval _cffi_d_g_ini_eval
#endif

static void _cffi_d_g_run_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  g_run_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_g_run_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "g_run_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { g_run_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_g_run_eval _cffi_d_g_run_eval
#endif

static void _cffi_d_h_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  h_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_h_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "h_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { h_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_h_eval _cffi_d_h_eval
#endif

static void _cffi_d_sp_Fu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Fu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Fu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Fu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Fu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Fu_run_num_eval _cffi_d_sp_Fu_run_num_eval
#endif

static void _cffi_d_sp_Fu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Fu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Fu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Fu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Fu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Fu_run_up_eval _cffi_d_sp_Fu_run_up_eval
#endif

static void _cffi_d_sp_Fu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Fu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Fu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Fu_run_xy_eval _cffi_d_sp_Fu_run_xy_eval
#endif

static void _cffi_d_sp_Gu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Gu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Gu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Gu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Gu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Gu_run_num_eval _cffi_d_sp_Gu_run_num_eval
#endif

static void _cffi_d_sp_Gu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Gu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Gu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Gu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Gu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Gu_run_up_eval _cffi_d_sp_Gu_run_up_eval
#endif

static void _cffi_d_sp_Gu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Gu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Gu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Gu_run_xy_eval _cffi_d_sp_Gu_run_xy_eval
#endif

static void _cffi_d_sp_Hu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hu_run_num_eval _cffi_d_sp_Hu_run_num_eval
#endif

static void _cffi_d_sp_Hu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hu_run_up_eval _cffi_d_sp_Hu_run_up_eval
#endif

static void _cffi_d_sp_Hu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hu_run_xy_eval _cffi_d_sp_Hu_run_xy_eval
#endif

static void _cffi_d_sp_Hx_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hx_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hx_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hx_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hx_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hx_run_num_eval _cffi_d_sp_Hx_run_num_eval
#endif

static void _cffi_d_sp_Hx_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hx_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hx_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hx_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hx_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hx_run_up_eval _cffi_d_sp_Hx_run_up_eval
#endif

static void _cffi_d_sp_Hx_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hx_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hx_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hx_run_xy_eval _cffi_d_sp_Hx_run_xy_eval
#endif

static void _cffi_d_sp_Hy_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hy_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hy_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hy_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hy_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hy_run_num_eval _cffi_d_sp_Hy_run_num_eval
#endif

static void _cffi_d_sp_Hy_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hy_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hy_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hy_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hy_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hy_run_up_eval _cffi_d_sp_Hy_run_up_eval
#endif

static void _cffi_d_sp_Hy_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hy_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hy_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hy_run_xy_eval _cffi_d_sp_Hy_run_xy_eval
#endif

static void _cffi_d_sp_jac_ini_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_ini_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_ini_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_ini_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_ini_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_ini_num_eval _cffi_d_sp_jac_ini_num_eval
#endif

static void _cffi_d_sp_jac_ini_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_ini_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_ini_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_ini_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_ini_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_ini_up_eval _cffi_d_sp_jac_ini_up_eval
#endif

static void _cffi_d_sp_jac_ini_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_ini_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_ini_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_ini_xy_eval _cffi_d_sp_jac_ini_xy_eval
#endif

static void _cffi_d_sp_jac_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_run_num_eval _cffi_d_sp_jac_run_num_eval
#endif

static void _cffi_d_sp_jac_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_run_up_eval _cffi_d_sp_jac_run_up_eval
#endif

static void _cffi_d_sp_jac_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_run_xy_eval _cffi_d_sp_jac_run_xy_eval
#endif

static void _cffi_d_sp_jac_trap_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_trap_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_trap_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_trap_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_trap_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_trap_num_eval _cffi_d_sp_jac_trap_num_eval
#endif

static void _cffi_d_sp_jac_trap_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_trap_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_trap_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_trap_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_trap_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_trap_up_eval _cffi_d_sp_jac_trap_up_eval
#endif

static void _cffi_d_sp_jac_trap_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_trap_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_trap_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_trap_xy_eval _cffi_d_sp_jac_trap_xy_eval
#endif

static const struct _cffi_global_s _cffi_globals[] = {
  { "de_Fu_run_num_eval", (void *)_cffi_f_de_Fu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Fu_run_num_eval },
  { "de_Fu_run_up_eval", (void *)_cffi_f_de_Fu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Fu_run_up_eval },
  { "de_Fu_run_xy_eval", (void *)_cffi_f_de_Fu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Fu_run_xy_eval },
  { "de_Gu_run_num_eval", (void *)_cffi_f_de_Gu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Gu_run_num_eval },
  { "de_Gu_run_up_eval", (void *)_cffi_f_de_Gu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Gu_run_up_eval },
  { "de_Gu_run_xy_eval", (void *)_cffi_f_de_Gu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Gu_run_xy_eval },
  { "de_Hu_run_num_eval", (void *)_cffi_f_de_Hu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hu_run_num_eval },
  { "de_Hu_run_up_eval", (void *)_cffi_f_de_Hu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hu_run_up_eval },
  { "de_Hu_run_xy_eval", (void *)_cffi_f_de_Hu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hu_run_xy_eval },
  { "de_Hx_run_num_eval", (void *)_cffi_f_de_Hx_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hx_run_num_eval },
  { "de_Hx_run_up_eval", (void *)_cffi_f_de_Hx_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hx_run_up_eval },
  { "de_Hx_run_xy_eval", (void *)_cffi_f_de_Hx_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hx_run_xy_eval },
  { "de_Hy_run_num_eval", (void *)_cffi_f_de_Hy_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hy_run_num_eval },
  { "de_Hy_run_up_eval", (void *)_cffi_f_de_Hy_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hy_run_up_eval },
  { "de_Hy_run_xy_eval", (void *)_cffi_f_de_Hy_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hy_run_xy_eval },
  { "de_jac_ini_num_eval", (void *)_cffi_f_de_jac_ini_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_ini_num_eval },
  { "de_jac_ini_up_eval", (void *)_cffi_f_de_jac_ini_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_ini_up_eval },
  { "de_jac_ini_xy_eval", (void *)_cffi_f_de_jac_ini_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_ini_xy_eval },
  { "de_jac_run_num_eval", (void *)_cffi_f_de_jac_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_num_eval },
  { "de_jac_run_up_eval", (void *)_cffi_f_de_jac_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_up_eval },
  { "de_jac_run_xy_eval", (void *)_cffi_f_de_jac_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_xy_eval },
  { "de_jac_trap_num_eval", (void *)_cffi_f_de_jac_trap_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_trap_num_eval },
  { "de_jac_trap_up_eval", (void *)_cffi_f_de_jac_trap_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_trap_up_eval },
  { "de_jac_trap_xy_eval", (void *)_cffi_f_de_jac_trap_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_trap_xy_eval },
  { "f_ini_eval", (void *)_cffi_f_f_ini_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_f_ini_eval },
  { "f_run_eval", (void *)_cffi_f_f_run_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_f_run_eval },
  { "g_ini_eval", (void *)_cffi_f_g_ini_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_g_ini_eval },
  { "g_run_eval", (void *)_cffi_f_g_run_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_g_run_eval },
  { "h_eval", (void *)_cffi_f_h_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_h_eval },
  { "sp_Fu_run_num_eval", (void *)_cffi_f_sp_Fu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Fu_run_num_eval },
  { "sp_Fu_run_up_eval", (void *)_cffi_f_sp_Fu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Fu_run_up_eval },
  { "sp_Fu_run_xy_eval", (void *)_cffi_f_sp_Fu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Fu_run_xy_eval },
  { "sp_Gu_run_num_eval", (void *)_cffi_f_sp_Gu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Gu_run_num_eval },
  { "sp_Gu_run_up_eval", (void *)_cffi_f_sp_Gu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Gu_run_up_eval },
  { "sp_Gu_run_xy_eval", (void *)_cffi_f_sp_Gu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Gu_run_xy_eval },
  { "sp_Hu_run_num_eval", (void *)_cffi_f_sp_Hu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hu_run_num_eval },
  { "sp_Hu_run_up_eval", (void *)_cffi_f_sp_Hu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hu_run_up_eval },
  { "sp_Hu_run_xy_eval", (void *)_cffi_f_sp_Hu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hu_run_xy_eval },
  { "sp_Hx_run_num_eval", (void *)_cffi_f_sp_Hx_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hx_run_num_eval },
  { "sp_Hx_run_up_eval", (void *)_cffi_f_sp_Hx_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hx_run_up_eval },
  { "sp_Hx_run_xy_eval", (void *)_cffi_f_sp_Hx_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hx_run_xy_eval },
  { "sp_Hy_run_num_eval", (void *)_cffi_f_sp_Hy_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hy_run_num_eval },
  { "sp_Hy_run_up_eval", (void *)_cffi_f_sp_Hy_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hy_run_up_eval },
  { "sp_Hy_run_xy_eval", (void *)_cffi_f_sp_Hy_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hy_run_xy_eval },
  { "sp_jac_ini_num_eval", (void *)_cffi_f_sp_jac_ini_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_ini_num_eval },
  { "sp_jac_ini_up_eval", (void *)_cffi_f_sp_jac_ini_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_ini_up_eval },
  { "sp_jac_ini_xy_eval", (void *)_cffi_f_sp_jac_ini_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_ini_xy_eval },
  { "sp_jac_run_num_eval", (void *)_cffi_f_sp_jac_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_run_num_eval },
  { "sp_jac_run_up_eval", (void *)_cffi_f_sp_jac_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_run_up_eval },
  { "sp_jac_run_xy_eval", (void *)_cffi_f_sp_jac_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_run_xy_eval },
  { "sp_jac_trap_num_eval", (void *)_cffi_f_sp_jac_trap_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_trap_num_eval },
  { "sp_jac_trap_up_eval", (void *)_cffi_f_sp_jac_trap_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_trap_up_eval },
  { "sp_jac_trap_xy_eval", (void *)_cffi_f_sp_jac_trap_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_trap_xy_eval },
};

static const struct _cffi_type_context_s _cffi_type_context = {
  _cffi_types,
  _cffi_globals,
  NULL,  /* no fields */
  NULL,  /* no struct_unions */
  NULL,  /* no enums */
  NULL,  /* no typenames */
  53,  /* num_globals */
  0,  /* num_struct_unions */
  0,  /* num_enums */
  0,  /* num_typenames */
  NULL,  /* no includes */
  9,  /* num_types */
  0,  /* flags */
};

#ifdef __GNUC__
#  pragma GCC visibility push(default)  /* for -fvisibility= */
#endif

#ifdef PYPY_VERSION
PyMODINIT_FUNC
_cffi_pypyinit_hola_cffi(const void *p[])
{
    p[0] = (const void *)0x2601;
    p[1] = &_cffi_type_context;
#if PY_MAJOR_VERSION >= 3
    return NULL;
#endif
}
#  ifdef _MSC_VER
     PyMODINIT_FUNC
#  if PY_MAJOR_VERSION >= 3
     PyInit_hola_cffi(void) { return NULL; }
#  else
     inithola_cffi(void) { }
#  endif
#  endif
#elif PY_MAJOR_VERSION >= 3
PyMODINIT_FUNC
PyInit_hola_cffi(void)
{
  return _cffi_init("hola_cffi", 0x2601, &_cffi_type_context);
}
#else
PyMODINIT_FUNC
inithola_cffi(void)
{
  _cffi_init("hola_cffi", 0x2601, &_cffi_type_context);
}
#endif

#ifdef __GNUC__
#  pragma GCC visibility pop
#endif
